(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5860,        204]*)
(*NotebookOutlinePosition[      6490,        226]*)
(*  CellTagsIndexPosition[      6446,        222]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "Problem 9.7 from textbook\n\nThe finite element model corresponds to \
linear interpolation elements. Two elements are used:\n     ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(e\_1\)\(\ \ \ \ \ \ \ \ \ \ \)\(e\_2\)\(\ \ \ \ \
\ \ \)\)\)]],
  "\no------o-------o\n",
  Cell[BoxData[
      \(TraditionalForm\`U\_1\ \ \ \ \ \ U\_2\ \ \ \ \ \ \ \ U\_\(\(3\)\(\ \ \
\ \ \ \)\)\)]],
  "\n\nThe  stiffness matrix of a generic element is:\n",
  Cell[BoxData[
      \(TraditionalForm\`K\^e = \(\(E\^e\) A\^e\)\/L\^e\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {"1", \(-1\)},
              {\(-1\), "1"}
              }], ")"}], TraditionalForm]]],
  "\nThe assembly is:"
}], "Subtitle"],

Cell[BoxData[
    RowBox[{
      RowBox[{"K", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(EA\_1\/L\_1\), \(-\(EA\_1\/L\_1\)\), "0"},
              {\(-\(EA\_1\/L\_1\)\), \(EA\_1\/L\_1 + 
                  EA\_2\/L\_2\), \(-\(EA\_2\/L\_2\)\)},
              {"0", \(-\(EA\_2\/L\_2\)\), \(EA\_2\/L\_2\)}
              }], ")"}]}], ";"}]], "Input",
  FontSize->24]
}, Open  ]],

Cell[CellGroupData[{

Cell["The force vector is:", "Subtitle"],

Cell[BoxData[
    RowBox[{
      RowBox[{"r", "=", " ", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(R\_1\)},
                {\(2\ P\)},
                {\(R\_2\)}
                }], ")"}], "//", "Flatten"}]}], ";"}]], "Input",
  FontSize->24]
}, Open  ]],

Cell[CellGroupData[{

Cell["The solution vector is defined as:", "Subtitle"],

Cell[BoxData[
    RowBox[{
      RowBox[{"u", " ", "=", " ", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"0"},
                {\(U\_2\)},
                {"0"}
                }], ")"}], "//", "Flatten"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The solution is obtained doing:", "Subtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(solution\  = \ 
      Solve[K . u \[Equal] r, \ {R\_1, U\_2, R\_2}] // Flatten\)], "Input"],

Cell[BoxData[
    \({R\_1 \[Rule] \(-\(\(2\ P\ EA\_1\ L\_2\)\/\(EA\_2\ L\_1 + 
                EA\_1\ L\_2\)\)\), 
      R\_2 \[Rule] \(-\(\(2\ P\ EA\_2\ L\_1\)\/\(EA\_2\ L\_1 + 
                EA\_1\ L\_2\)\)\), 
      U\_2 \[Rule] \(2\ P\ L\_1\ L\_2\)\/\(EA\_2\ L\_1 + EA\_1\ L\_2\)}\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(values\  = \ {P \[Rule] \ 50000, \ \ EA\_1 \[Rule] \ 
            200\ \(10\^9\) 60\ 10\^\(-6\), \ 
          EA\_2 \[Rule] \ 70\ 10\^9\ 600\ 10\^\(-6\), \ 
          L\_1 \[Rule] \ 0.01, \ 
          L\_2 \[Rule] \ 0.02};\)\), "\[IndentingNewLine]", 
    \(sol\  = \ solution\  /. \ values\)}], "Input"],

Cell[BoxData[
    \({R\_1 \[Rule] \(-36363.63636363637`\), 
      R\_2 \[Rule] \(-63636.36363636364`\), 
      U\_2 \[Rule] 0.000030303030303030306`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The strains in the elements are:", "Subtitle"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Epsilon]\_1 = \ \(U\_2\/L\_1 /. \ sol\)\  /. \ 
        values\), "\[IndentingNewLine]", 
    \(\[Epsilon]\_2 = \ \(\((\(-U\_2\))\)\/L\_2 /. \ sol\)\  /. \ 
        values\)}], "Input",
  FontSize->18],

Cell[BoxData[
    \(0.0030303030303030307`\)], "Output"],

Cell[BoxData[
    \(\(-0.0015151515151515154`\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The stresses and forces in the elements are:", "Subtitle"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Sigma]\_1 = \ \ 200\ \(10\^9\) \[Epsilon]\_1\), \
"\[IndentingNewLine]", 
    \(P\_1 = \ \(EA\_1\) \[Epsilon]\_1 /. \ values\), "\[IndentingNewLine]", 
    \(\[Sigma]\_2 = \ \ 70\ \(10\^9\) \[Epsilon]\_2\), "\[IndentingNewLine]", \

    \(P\_2 = \ \(EA\_2\) \[Epsilon]\_2 /. \ values\)}], "Input",
  FontSize->18],

Cell[BoxData[
    \(6.060606060606062`*^8\)], "Output"],

Cell[BoxData[
    \(36363.63636363637`\)], "Output"],

Cell[BoxData[
    \(\(-1.0606060606060608`*^8\)\)], "Output"],

Cell[BoxData[
    \(\(-63636.36363636365`\)\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1600}, {0, 1200}},
WindowSize->{673, 773},
WindowMargins->{{Automatic, 7}, {Automatic, 140}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 736, 20, 373, "Subtitle"],
Cell[2515, 75, 381, 9, 144, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2933, 89, 40, 0, 51, "Subtitle"],
Cell[2976, 91, 270, 9, 100, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3283, 105, 54, 0, 51, "Subtitle"],
Cell[3340, 107, 249, 8, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3626, 120, 51, 0, 51, "Subtitle"],

Cell[CellGroupData[{
Cell[3702, 124, 111, 2, 27, "Input"],
Cell[3816, 128, 302, 6, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4155, 139, 327, 6, 67, "Input"],
Cell[4485, 147, 163, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4697, 156, 52, 0, 51, "Subtitle"],

Cell[CellGroupData[{
Cell[4774, 160, 224, 5, 119, "Input"],
Cell[5001, 167, 56, 1, 27, "Output"],
Cell[5060, 170, 61, 1, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5170, 177, 64, 0, 51, "Subtitle"],

Cell[CellGroupData[{
Cell[5259, 181, 336, 7, 108, "Input"],
Cell[5598, 190, 55, 1, 29, "Output"],
Cell[5656, 193, 52, 1, 27, "Output"],
Cell[5711, 196, 61, 1, 29, "Output"],
Cell[5775, 199, 57, 1, 27, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

