(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     36666,        990]*)
(*NotebookOutlinePosition[     37374,       1015]*)
(*  CellTagsIndexPosition[     37330,       1011]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(Clear["\<Global`*\>"]; Off[General::spell, General::spell1];\)], "Input",\

  FontSize->24],

Cell["\<\
The finite element method V
Formulation of finite element matrices for an Euler-Bernoulli beam\
\>", \
"Title",
  FontSize->24],

Cell[CellGroupData[{

Cell["Hermite Cubic Polynomials (used as basis functions)", "Subtitle",
  FontSize->24],

Cell[BoxData[{
    \(\(\[Phi]\_1\  = \ 
        1\  - \ 3\ \((\[Xi]\/h)\)\^2 + \ 
          2\ \((\[Xi]\/h)\)\^3;\)\), "\[IndentingNewLine]", 
    \(\(\[Phi]\_2 = \[Xi]\ \((1\  - \ \[Xi]\/h)\)\^2;\)\), "\
\[IndentingNewLine]", 
    \(\(\[Phi]\_3 = \ 
        3 \((\[Xi]\/h)\)\^2 - \ 
          2\ \((\[Xi]\/h)\)\^3;\)\), "\[IndentingNewLine]", 
    \(\(\[Phi]\_4\  = \ \[Xi]\ \((\((\[Xi]\/h)\)\^2 - \ \[Xi]\/h)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Phi]\  = \ Table[\[Phi]\_k, {k, 4}];\)\)}], "Input",
  FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Phi]\  /. \ \[Xi] \[Rule] 0\), "\[IndentingNewLine]", 
    \(\[PartialD]\_\[Xi] \[Phi]\  /. \ \[Xi] \[Rule] 
        0\), "\[IndentingNewLine]", 
    \(\[Phi]\  /. \ \[Xi] \[Rule] h\), "\[IndentingNewLine]", 
    \(\[PartialD]\_\[Xi] \[Phi]\  /. \ \[Xi] \[Rule] h\)}], "Input",
  FontSize->24],

Cell[BoxData[
    \({1, 0, 0, 0}\)], "Output"],

Cell[BoxData[
    \({0, 1, 0, 0}\)], "Output"],

Cell[BoxData[
    \({0, 0, 1, 0}\)], "Output"],

Cell[BoxData[
    \({0, 0, 0, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{\(Evaluate[\[Phi] /. h \[Rule] 1]\), ",", 
          " ", \({\[Xi], 0, 1}\), ",", 
          
          StyleBox[\(PlotStyle \[Rule] {{RGBColor[1, 0, 0], 
                  Thickness[0.01]}, {RGBColor[0, 1, 0], 
                  Thickness[0.01]}, {RGBColor[0, 0, 1], 
                  Thickness[0.01]}, {RGBColor[0, 1, 1], Thickness[0.01]}}\),
            FontSize->16]}], "]"}], ";"}]], "Input",
  FontSize->24],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.090664 0.512655 [
[.21429 .07816 -9 -9 ]
[.21429 .07816 9 0 ]
[.40476 .07816 -9 -9 ]
[.40476 .07816 9 0 ]
[.59524 .07816 -9 -9 ]
[.59524 .07816 9 0 ]
[.78571 .07816 -9 -9 ]
[.78571 .07816 9 0 ]
[.97619 .07816 -3 -9 ]
[.97619 .07816 3 0 ]
[.01131 .19319 -18 -4.5 ]
[.01131 .19319 0 4.5 ]
[.01131 .29573 -18 -4.5 ]
[.01131 .29573 0 4.5 ]
[.01131 .39826 -18 -4.5 ]
[.01131 .39826 0 4.5 ]
[.01131 .50079 -18 -4.5 ]
[.01131 .50079 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .09066 m
.21429 .09691 L
s
[(0.2)] .21429 .07816 0 1 Mshowa
.40476 .09066 m
.40476 .09691 L
s
[(0.4)] .40476 .07816 0 1 Mshowa
.59524 .09066 m
.59524 .09691 L
s
[(0.6)] .59524 .07816 0 1 Mshowa
.78571 .09066 m
.78571 .09691 L
s
[(0.8)] .78571 .07816 0 1 Mshowa
.97619 .09066 m
.97619 .09691 L
s
[(1)] .97619 .07816 0 1 Mshowa
.125 Mabswid
.07143 .09066 m
.07143 .09441 L
s
.11905 .09066 m
.11905 .09441 L
s
.16667 .09066 m
.16667 .09441 L
s
.2619 .09066 m
.2619 .09441 L
s
.30952 .09066 m
.30952 .09441 L
s
.35714 .09066 m
.35714 .09441 L
s
.45238 .09066 m
.45238 .09441 L
s
.5 .09066 m
.5 .09441 L
s
.54762 .09066 m
.54762 .09441 L
s
.64286 .09066 m
.64286 .09441 L
s
.69048 .09066 m
.69048 .09441 L
s
.7381 .09066 m
.7381 .09441 L
s
.83333 .09066 m
.83333 .09441 L
s
.88095 .09066 m
.88095 .09441 L
s
.92857 .09066 m
.92857 .09441 L
s
.25 Mabswid
0 .09066 m
1 .09066 L
s
.02381 .19319 m
.03006 .19319 L
s
[(0.2)] .01131 .19319 1 0 Mshowa
.02381 .29573 m
.03006 .29573 L
s
[(0.4)] .01131 .29573 1 0 Mshowa
.02381 .39826 m
.03006 .39826 L
s
[(0.6)] .01131 .39826 1 0 Mshowa
.02381 .50079 m
.03006 .50079 L
s
[(0.8)] .01131 .50079 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .1163 m
.02756 .1163 L
s
.02381 .14193 m
.02756 .14193 L
s
.02381 .16756 m
.02756 .16756 L
s
.02381 .21883 m
.02756 .21883 L
s
.02381 .24446 m
.02756 .24446 L
s
.02381 .27009 m
.02756 .27009 L
s
.02381 .32136 m
.02756 .32136 L
s
.02381 .34699 m
.02756 .34699 L
s
.02381 .37262 m
.02756 .37262 L
s
.02381 .42389 m
.02756 .42389 L
s
.02381 .44952 m
.02756 .44952 L
s
.02381 .47516 m
.02756 .47516 L
s
.02381 .52642 m
.02756 .52642 L
s
.02381 .55205 m
.02756 .55205 L
s
.02381 .57769 m
.02756 .57769 L
s
.02381 .06503 m
.02756 .06503 L
s
.02381 .0394 m
.02756 .0394 L
s
.02381 .01377 m
.02756 .01377 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .60332 m
.02499 .60332 L
.02605 .60331 L
.02729 .6033 L
.02846 .60328 L
.03053 .60324 L
.03279 .60318 L
.03527 .6031 L
.0379 .60299 L
.04262 .60273 L
.05205 .60199 L
.06244 .60086 L
.07293 .59937 L
.0842 .5974 L
.10458 .59288 L
.1458 .58024 L
.18551 .564 L
.22371 .54505 L
.26435 .52173 L
.30348 .49666 L
.34506 .46768 L
.38513 .43794 L
.42368 .40809 L
.46468 .37545 L
.50417 .34362 L
.54214 .31305 L
.58257 .28099 L
.62148 .25104 L
.66284 .22064 L
.70268 .19322 L
.74101 .16901 L
.78179 .14602 L
.82106 .12704 L
.85881 .11211 L
.87978 .10536 L
.89901 .10022 L
.91786 .0962 L
.92745 .09455 L
.9377 .09311 L
.94804 .09198 L
.95744 .09125 L
.96198 .091 L
.96436 .0909 L
.96689 .09081 L
.9691 .09075 L
.97027 .09072 L
.97153 .0907 L
.97269 .09068 L
.97374 .09067 L
.9748 .09067 L
Mistroke
.97581 .09066 L
.97619 .09066 L
Mfstroke
0 1 0 r
.02381 .09066 m
.06244 .10981 L
.10458 .12708 L
.14415 .14011 L
.18221 .14992 L
.20342 .15432 L
.22272 .15768 L
.24299 .16059 L
.26171 .16274 L
.28086 .16442 L
.29094 .16511 L
.30164 .16569 L
.31105 .16608 L
.31624 .16625 L
.32117 .16638 L
.32574 .16647 L
.32816 .16651 L
.33073 .16655 L
.33311 .16657 L
.33527 .16659 L
.33631 .1666 L
.33743 .1666 L
.3385 .16661 L
.33947 .16661 L
.34074 .16661 L
.34193 .16661 L
.34301 .16661 L
.34417 .16661 L
.34544 .1666 L
.34679 .1666 L
.34921 .16658 L
.35144 .16656 L
.35353 .16653 L
.3583 .16645 L
.36349 .16634 L
.36824 .16621 L
.37896 .16584 L
.38877 .1654 L
.39789 .16491 L
.41859 .16351 L
.45763 .1599 L
.49913 .15486 L
.53911 .14909 L
.57758 .14288 L
.6185 .13582 L
.6579 .12879 L
.69579 .12202 L
.73613 .11503 L
.77495 .10872 L
.81623 .1027 L
Mistroke
.85599 .0978 L
.89423 .09413 L
.91394 .09271 L
.93493 .09158 L
.94515 .09119 L
.95052 .09103 L
.95619 .09089 L
.96116 .09079 L
.96379 .09075 L
.96661 .09072 L
.96795 .0907 L
.96921 .09069 L
.97043 .09068 L
.97157 .09068 L
.97264 .09067 L
.97378 .09067 L
.97493 .09066 L
.97619 .09066 L
Mfstroke
0 0 1 r
.02381 .09066 m
.02499 .09067 L
.02605 .09067 L
.02729 .09068 L
.02846 .0907 L
.03053 .09074 L
.03279 .0908 L
.03527 .09088 L
.0379 .091 L
.04262 .09126 L
.05205 .09199 L
.06244 .09313 L
.07293 .09461 L
.0842 .09659 L
.10458 .1011 L
.1458 .11374 L
.18551 .12998 L
.22371 .14894 L
.26435 .17225 L
.30348 .19732 L
.34506 .22631 L
.38513 .25604 L
.42368 .2859 L
.46468 .31853 L
.50417 .35036 L
.54214 .38093 L
.58257 .41299 L
.62148 .44295 L
.66284 .47335 L
.70268 .50076 L
.74101 .52498 L
.78179 .54796 L
.82106 .56694 L
.85881 .58188 L
.87978 .58862 L
.89901 .59377 L
.91786 .59779 L
.92745 .59943 L
.9377 .60087 L
.94804 .602 L
.95744 .60273 L
.96198 .60298 L
.96436 .60308 L
.96689 .60317 L
.9691 .60323 L
.97027 .60326 L
.97153 .60328 L
.97269 .6033 L
.97374 .60331 L
.9748 .60332 L
Mistroke
.97581 .60332 L
.97619 .60332 L
Mfstroke
0 1 1 r
.02381 .09066 m
.02499 .09066 L
.02605 .09066 L
.02729 .09066 L
.02846 .09065 L
.03053 .09064 L
.03279 .09062 L
.03527 .09059 L
.0379 .09055 L
.04262 .09047 L
.05205 .09023 L
.06244 .08985 L
.07293 .08937 L
.0842 .08873 L
.10458 .08729 L
.1458 .08333 L
.18551 .07839 L
.22371 .07282 L
.26435 .06622 L
.30348 .05944 L
.34506 .05201 L
.38513 .04487 L
.42368 .03823 L
.46468 .03166 L
.50417 .02603 L
.54214 .02146 L
.56329 .01935 L
.58257 .01773 L
.60255 .01639 L
.62148 .01547 L
.63113 .01513 L
.63642 .01499 L
.64138 .01488 L
.6456 .01481 L
.64777 .01478 L
.65014 .01476 L
.6526 .01474 L
.65394 .01473 L
.65518 .01472 L
.65635 .01472 L
.65742 .01472 L
.65865 .01472 L
.65981 .01472 L
.66096 .01472 L
.6622 .01472 L
.66337 .01473 L
.66443 .01473 L
.66705 .01475 L
.66953 .01478 L
.67445 .01486 L
Mistroke
.67982 .01497 L
.68446 .0151 L
.68939 .01526 L
.69827 .01564 L
.70858 .01619 L
.71972 .01695 L
.73991 .01876 L
.75988 .02111 L
.78096 .02424 L
.81899 .03167 L
.85946 .04229 L
.89842 .05536 L
.93984 .07256 L
.97619 .09066 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`030000003oool0oooo0?l0
ooooSP3oool00200oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool00`000000oooo0?oo
o`3o0?ooohh0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<000000?oo
o`3oool0j@3oool/003oogP0oooo000P0?ooo`800000fP3ooom9003oof/0oooo000P0?ooo`030000
003oool0oooo0=00ooooFP00oomS0?ooo`00803oool00`000000oooo0?ooo`390?ooofX00?ooFP3o
ool00200oooo00<000000?ooo`3oool0`@3ooolY003oobX0oooo9000oomE0?ooo`00803oool00`00
0000oooo0?ooo`2i0?ooob400?ooA`3ooolL003ooe00oooo000P0?ooo`030000003oool0oooo0;40
oooo8000oomH0?oooaX00?ooBP3oool00200oooo00<000000?ooo`3oool0[03ooolM003oofT0oooo
5@00oom60?ooo`00803oool00`000000oooo0?ooo`2V0?oooa`00?ooMP3ooolC003ood80oooo000P
0?ooo`030000003oool0oooo0:00oooo6P00oon30?oooa800?oo?P3oool00200oooo00<000000?oo
o`3oool0V03ooolJ003ooi00oooo4@00oolj0?ooo`00803oool200000940oooo7000oonJ0?oooa00
0?oo=`3oool00200oooo00<000000?ooo`3oool0R`3ooolK003ooj@0oooo3P00oole0?ooo`00803o
ool00`000000oooo0?ooo`260?oooa/00?oo[@3oool=003ooc80oooo000P0?ooo`030000003oool0
oooo03l0oooo0P0000070?ooo`<000001P3oool6000002T0oooo6@00ool90?ooo`<00000=P3oool2
000000L0oooo0`0000080?ooo`<00000=`3oool2000000L0oooo0`0000070?ooo`@000004P3oool<
003oob80oooo1@0000080?ooo`00803oool00`000000oooo0?ooo`0n0?ooo`040000003oool0oooo
000000H0oooo0`0000060?ooo`8000000`3oool00`000000oooo0?ooo`0R0?oooaH00?oo1@3oool3
000000X0oooo00<000000?ooo`3oool0=03oool010000000oooo0?ooo`0000060?ooo`<000001`3o
ool00`000000oooo0?ooo`02000003D0oooo00@000000?ooo`3oool000001P3oool3000000H0oooo
0P0000020?ooo`800000503oool;003oob80oooo00<000000?ooo`3oool0203oool00200oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0`00
00070?ooo`8000008@3ooolF003oo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool3000000X0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo0`0000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0`0000060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0503oool<003ooal0oooo00<000000?ooo`3oool0203o
ool00200oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00h0oooo0P00000J0?oooaL00?oo1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00`0oooo1P00000d0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool;
003ooad0oooo00<000000?ooo`3oool0203oool00200oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo0P00000D0?oooaL00?oo2P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000000e
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool200000080oooo0P00000d
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool5000001`0oooo2`00oolJ
0?ooo`030000003oool0oooo00P0oooo000P0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`8000003P3ooolF003ooa00oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000003D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`D00000=@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00d0oooo1000000O0?ooo`/00?oo603oool00`000000oooo0?ooo`08
0?ooo`00803oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`060?oooaH00?oo5P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo0P0000000`3oool000000?ooo`0d0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01l0oooo2`00oolE0?ooo`030000003oool0oooo00P0oooo000P0?ooo`800000?P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool0oooo5P00oolK0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000e0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0280oooo2P00oolC0?ooo`030000003oool0oooo00P0oooo000P0?ooo`03
0000003oool0oooo03h0oooo00@000000?ooo`3oool000003`3oool2000000030?ooo`00ool00?oo
01@00?oo8P3oool010000000oooo0?ooo`00000B0?ooo`800000=P3oool010000000oooo0?ooo`00
000@0?ooo`800000>03oool010000000oooo0?ooo`00000?0?ooo`8000000P3oool2000002H0oooo
2P00ool?0?ooo`030000003oool0000000X0oooo000P0?ooo`030000003oool0oooo03l0oooo0P00
000=0?oooaL00?oo:03oool2000001<0oooo0P00000g0?ooo`8000004`3oool3000003H0oooo0P00
000A0?ooo`@00000:@3oool;003oo`d0oooo0P00000:0?ooo`00803oool00`000000oooo0?ooo`17
0?oooaT00?ooo`3oool=0?ooo`X00?oo5`3oool00200oooo00<000000?ooo`3oool0?`3ooolK003o
ool0oooo5@3oool:003ooaD0oooo000P0?ooo`030000003oool0oooo03L0oooo7@00oooo0?oooah0
oooo2@00oolC0?ooo`00803oool00`000000oooo0?ooo`0^0?ooob400?ooo`3ooolU0?ooo`X00?oo
403oool00200oooo00<000000?ooo`3oool09P3ooolQ003oool0oooo;`3oool:003oo`h0oooo000P
0?ooo`030000003oool0oooo01h0oooo8P00oooo0?ooocP0oooo2P00ool<0?ooo`007`3oool2003o
00h0oooo:`00oooo0?oood<0oooo2P00ool:0?ooo`007P3ooold003oool0oooo>P3ooolD003o00T0
0?oo203oool001H0oooo2000000/003oool00000<`00000U003o00L00?oo1`0000010?ooo`007P3o
oolT003oo`D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool01`3oool_003o00@00?oo2@3oool001h0oooo4P00oolB
0000ob/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool04P3oooli003o00800?oo2@3oool00200oooo00<000000?oo
o`00o`001`00o`000`3oool0003o0000o`0H0000obP0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool02@3ooolY003o
00h0o`002`3oool00`000000oooo0?ooo`080?ooo`00803oool010000000oooo0?ooo`3oool8003o
00P0oooo50000?oo0?oooa@0oooo8@00o`000`3oool0o`000?l0000C0?l001h0oooo000P0?ooo`03
0000003oool0oooo00<0oooo2000o`0?0?ooo`h0003oo`3oool90?ooob800?l01@3oool@0?l002H0
oooo000P0?ooo`030000003oool0oooo00@0oooo2@00o`0A0?ooo`h0003oo`3ooolN003o00`0oooo
3P3o000Z0?ooo`00803oool00`000000oooo0?ooo`060?ooo`T00?l04P3oool>0000ooL0oooo6`00
o`0A0?ooo`d0o`00;P3oool00200oooo00<000000?ooo`3oool0203oool:003o01<0oooo30000?o_
0?oooaT00?l05P3oool<0?l00380oooo000P0?ooo`030000003oool0oooo00X0oooo2`00o`0C0?oo
o``0003oi`3ooolF003o01`0oooo2`3o000e0?ooo`00803oool2000000d0oooo2`00o`0D0?ooo`/0
003og`3ooolF003o01l0oooo303o000g0?ooo`00803oool00`000000oooo0?ooo`0?0?ooo`/00?l0
503oool;0000omH0oooo5`00o`0Q0?ooo``0o`00>P3oool00200oooo00<000000?ooo`3oool04@3o
ool;003o01D0oooo2P000?o?0?oooaL00?l0903oool;0?l003d0oooo000P0?ooo`030000003oool0
oooo01@0oooo2`00o`0D0?ooo`X0003ob03ooolF003o02L0oooo303o000o0?ooo`00803oool00`00
0000oooo0?ooo`0F0?ooo``00?l04`3oool;0000ol00oooo5@00o`0[0?ooo`/0o`00@P3oool00200
oooo00<000000?ooo`3oool06@3oool<003o01<0oooo2P000?nf0?oooaP00?l0;P3oool:0?l004D0
oooo000P0?ooo`030000003oool0oooo01`0oooo3000o`0B0?ooo`X0003o[03ooolK003o0340oooo
2P3o00170?ooo`00803oool00`000000oooo0?ooo`0N0?ooo`h00?l04@3oool90000ojD0oooo6`00
o`0d0?ooo`T0o`00BP3oool00200oooo00<000000?ooo`3oool08@3oool>003o0100oooo20000?nN
0?oooa`00?l0=`3oool90?l004`0oooo000P0?ooo`030000003oool0oooo02D0oooo3P00o`0>0?oo
o`P0003oUP3ooolJ003o03d0oooo2@3o001>0?ooo`00803oool00`000000oooo0?ooo`0X0?ooo`h0
0?l03@3oool80000ohl0oooo5`00o`130?ooo`T0o`00D03oool00200oooo0P00000/0?ooo`l00?l0
2`3oool80000ohP0oooo5P00o`170?ooo`T0o`00DP3oool00200oooo00<000000?ooo`3oool0;P3o
ool@003o00P0oooo2@000?n00?oooaH00?l0B`3oool90?l005@0oooo000P0?ooo`030000003oool0
oooo0380oooo4000o`060?ooo`T0003oMP3ooolI003o04h0oooo2@3o001F0?ooo`00803oool00`00
0000oooo0?ooo`0f0?oooa400?l00`3oool90000of`0oooo6`00o`1C0?ooo`P0o`00F03oool00200
oooo00<000000?ooo`3oool0>@3ooolC003o00T0003oHP3ooolN003o05H0oooo203o001J0?ooo`00
803oool00`000000oooo0?ooo`0m0?oooa400?l02@000?mG0?ooob800?l0F@3oool80?l005`0oooo
000P0?ooo`030000003oool0oooo0480oooo3P00o`080000odh0oooo8P00o`1O0?ooo`P0o`00GP3o
ool00200oooo00<000000?ooo`3oool0AP3oool<003o00P0003o3@00o`0g0?ooob800?l0IP3oool8
0?l005l0oooo000P0?ooo`030000003oool0oooo04h0oooo1P00o`080000oa<00?l08`3ooolU003o
06d0oooo203o001Q0?ooo`00803oool00`000000oooo0?ooo`1B0?ooo`@00?l020000?mA003o07<0
oooo203o001S0?ooo`00803oool2000005L0oooo00<00?l00000o`000?l01`000?m7003o07T0oooo
203o001U0?ooo`00803oool00`000000oooo0?ooo`1I0?ooo`T0003o103oooli003o0800oooo203o
001V0?ooo`00803oool00`000000oooo0?ooo`1K0?ooo`P0003o2`3ooolU003o08X0oooo203o001X
0?ooo`00803oool00`000000oooo0?ooo`1M0?ooo`L0003o^03oool70?l006X0oooo000P0?ooo`03
0000003oool0oooo05l0oooo1`000?nd0?ooo`L0o`00K03oool00200oooo00<000000?ooo`3oool0
H03oool70000ok40oooo203o001]0?ooo`00803oool00`000000oooo0?ooo`1R0?ooo`L0003o[P3o
ool70?l006l0oooo00000`3oool00000000000070?ooo`<000001P3oool6000000L0oooo00<00000
0?ooo`3oool0H`3oool70000oj/0oooo203o001`0?ooo`0000@000000?ooo`3oool000001P3oool3
000000H0oooo0P0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0I@3oool7
0000ojP0oooo1`3o001b0?ooo`00103oool00`000000oooo0?ooo`030?ooo`<000001`3oool20000
00X0oooo00<000000?ooo`3oool0IP3oool70000ojD0oooo1`3o001d0?ooo`00103oool00`000000
oooo0?ooo`0>0?ooo`8000002@3oool00`000000oooo0?ooo`1X0?ooo`L0003oX@3oool80?l007D0
oooo00040?ooo`030000003oool0oooo00l0oooo0P0000080?ooo`<00000J@3oool70000oil0oooo
1`3o001g0?ooo`00103oool00`000000oooo0?ooo`0@0?ooo`8000001`3oool00`000000oooo0?oo
o`1[0?ooo`L0003oW03oool70?l007P0oooo00040?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1/0?ooo`L0003oV@3oool70?l007X0oooo00040?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?oo
o`P0003oUP3oool70?l007/0oooo000010000000oooo0?ooo`00000?0?ooo`8000000P3oool20000
00L0oooo00<000000?ooo`3oool0K`3oool70000oi<0oooo1`3o001m0?ooo`0000<0oooo00000000
00004@3oool4000000P0oooo00<000000?ooo`3oool0L03oool80000oi00oooo1`3o001n0?ooo`00
803oool00`000000oooo0?ooo`1b0?ooo`L0003oS@3oool70?l00800oooo000P0?ooo`030000003o
ool0oooo07@0oooo1`000?n:0?ooo`L0o`00P@3oool00200oooo00<000000?ooo`3oool0M@3oool7
0000ohL0oooo1`3o00230?ooo`00803oool00`000000oooo0?ooo`1g0?ooo`L0003oQ03oool70?l0
08@0oooo000P0?ooo`800000N@3oool80000oh40oooo1P3o00260?ooo`00803oool00`000000oooo
0?ooo`1j0?ooo`L0003oOP3oool70?l008L0oooo000P0?ooo`030000003oool0oooo07/0oooo1`00
0?ml0?ooo`L0o`00R03oool00200oooo00<000000?ooo`3oool0O@3oool70000ogT0oooo1P3o002:
0?ooo`00803oool00`000000oooo0?ooo`1n0?ooo`L0003oMP3oool70?l008/0oooo000P0?ooo`03
0000003oool0oooo0800oooo1P000?md0?ooo`L0o`00S03oool00200oooo00<000000?ooo`3oool0
P@3oool60000og80oooo1P3o002>0?ooo`00803oool00`000000oooo0?ooo`220?ooo`L0003oKP3o
ool70?l008l0oooo000P0?ooo`030000003oool0oooo08<0oooo1`000?m/0?ooo`L0o`00T03oool0
0200oooo00<000000?ooo`3oool0Q@3oool60000ofX0oooo1P3o002B0?ooo`00803oool00`000000
oooo0?ooo`260?ooo`H0003oI`3oool70?l009<0oooo000P0?ooo`800000R03oool70000of@0oooo
1`3o002D0?ooo`00803oool00`000000oooo0?ooo`280?ooo`L0003oHP3oool60?l009H0oooo000P
0?ooo`030000003oool0oooo08X0oooo1P000?mO0?ooo`L0o`00U`3oool00200oooo00<000000?oo
o`3oool0R`3oool60000oed0oooo1`3o002H0?ooo`00803oool00`000000oooo0?ooo`2<0?ooo`H0
003oF`3oool60?l009X0oooo000P0?ooo`030000003oool0oooo08d0oooo1`000?mG0?ooo`L0o`00
V`3oool00200oooo00<000000?ooo`3oool0S`3oool60000oeD0oooo1`3o002L0?ooo`00803oool0
0`000000oooo0?ooo`2@0?ooo`H0003oD`3oool60?l009h0oooo000P0?ooo`030000003oool0oooo
0940oooo1`000?m?0?ooo`L0o`00W`3oool00200oooo00<000000?ooo`3oool0TP3oool70000odd0
oooo1`3o002P0?ooo`00803oool2000009D0oooo1P000?m;0?ooo`H0o`00XP3oool00200oooo00<0
00000?ooo`3oool0U@3oool70000odL0oooo1`3o002S0?ooo`00803oool00`000000oooo0?ooo`2F
0?ooo`L0003oA@3oool70?l00:@0oooo000P0?ooo`030000003oool0oooo09P0oooo1P000?m30?oo
o`H0o`00YP3oool00200oooo00<000000?ooo`3oool0V@3oool70000od00oooo1P3o002W0?ooo`00
803oool00`000000oooo0?ooo`2J0?ooo`L0003o?@3oool70?l00:P0oooo000P0?ooo`030000003o
ool0oooo09`0oooo1P000?lk0?ooo`H0o`00ZP3oool000030?ooo`000000000000L0oooo0`000009
0?ooo`<000001`3oool00`000000oooo0?ooo`2M0?ooo`L0003o>03oool60?l00:/0oooo00001000
0000oooo0?ooo`0000060?ooo`<000002P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo09h0oooo1`000?le0?ooo`L0o`00[03oool000@0oooo00<000000?ooo`3oool00`3oool30000
00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2P0?ooo`H0003o<`3oool70?l0
0:d0oooo00040?ooo`030000003oool0oooo00`0oooo1P0000070?ooo`030000003oool0oooo0:40
oooo1`000?l`0?ooo`H0o`00[`3oool000@0oooo00<000000?ooo`3oool0303oool01@000000oooo
0?ooo`3oool0000000P0oooo0`00002R0?ooo`L0003o;@3oool70?l00;00oooo00040?ooo`030000
003oool0oooo00d0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`2T0?ooo`H0
003o:`3oool70?l00;40oooo00040?ooo`030000003oool0oooo00d0oooo0P0000000`3oool00000
0?ooo`070?ooo`030000003oool0oooo0:D0oooo1`000?lX0?ooo`H0o`00/`3oool000@0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo000000080?ooo`030000003oool0oooo0:H0oooo1`00
0?lU0?ooo`L0o`00]03oool000040000003oool0oooo00000180oooo0P0000080?ooo`030000003o
ool0oooo0:P0oooo1P000?lS0?ooo`L0o`00]@3oool000030?ooo`000000000001<0oooo0P000008
0?ooo`030000003oool0oooo0:T0oooo1`000?lP0?ooo`H0o`00]`3oool00200oooo00<000000?oo
o`3oool0ZP3oool70000oah0oooo1P3o002h0?ooo`00803oool00`000000oooo0?ooo`2/0?ooo`H0
003o6`3oool70?l00;T0oooo000P0?ooo`030000003oool0oooo0:d0oooo1P000?lI0?ooo`H0o`00
^`3oool00200oooo00<000000?ooo`3oool0[P3oool70000oaH0oooo1P3o002l0?ooo`00803oool2
00000;40oooo1P000?lD0?ooo`H0o`00_@3oool00200oooo00<000000?ooo`3oool0/@3oool60000
oa40oooo1`3o002n0?ooo`00803oool00`000000oooo0?ooo`2b0?ooo`H0003o3`3oool60?l00<00
oooo000P0?ooo`030000003oool0oooo0;<0oooo1`000?l<0?ooo`H0o`00`@3oool00200oooo00<0
00000?ooo`3oool0]03oool70000o`X0oooo1P3o00320?ooo`00803oool00`000000oooo0?ooo`2f
0?ooo`H0003o1`3oool70?l00<<0oooo000P0?ooo`030000003oool0oooo0;L0oooo1P000?l50?oo
o`H0o`00a@3oool00200oooo00<000000?ooo`3oool0^03oool70000o`80oooo1P3o00360?ooo`00
803oool00`000000oooo0?ooo`2i0?ooo`L0003o1P3o00370?ooo`00803oool00`000000oooo0?oo
o`2k0?ooo`H0003o103o00380?ooo`00803oool00`000000oooo0?ooo`2l0?ooo`H0003o00<0o`00
0?ooo`3oool0b03oool00200oooo0P00002m0?ooo`030?l000000?l0003o00@0003obP3oool00200
oooo00<000000?ooo`3oool0^`3oool30?l000L0003ob03oool00200oooo00<000000?ooo`3oool0
^@3oool70?l000H0003oa`3oool00200oooo00<000000?ooo`3oool0^03oool70?l00080oooo1P00
0?o60?ooo`00803oool00`000000oooo0?ooo`2g0?ooo`H0o`001@3oool60000olD0oooo000P0?oo
o`030000003oool0oooo0;H0oooo1P3o00070?ooo`H0003oa03oool00200oooo00<000000?ooo`3o
ool0]03oool70?l000T0oooo1P000?o30?ooo`00803oool00`000000oooo0?ooo`2c0?ooo`L0o`00
2`3oool60000ol80oooo000P0?ooo`030000003oool0oooo0;80oooo1P3o000?0?ooo`H0003o`03o
ool00200oooo00<000000?ooo`3oool0/@3oool60?l00140oooo1P000?no0?ooo`00803oool20000
0;40oooo1P3o000C0?ooo`H0003o_P3oool00200oooo00<000000?ooo`3oool0[P3oool70?l001D0
oooo1P000?nm0?ooo`00803oool00`000000oooo0?ooo`2]0?ooo`H0o`00603oool60000ok`0oooo
000P0?ooo`030000003oool0oooo0:`0oooo1P3o000J0?ooo`H0003o^`3oool00200oooo00<00000
0?ooo`3oool0Z`3oool60?l001`0oooo1`000?ni0?ooo`00803oool00`000000oooo0?ooo`2Y0?oo
o`L0o`007`3oool60000okP0oooo000P0?ooo`030000003oool0oooo0:P0oooo1`3o000Q0?ooo`H0
003o]`3oool000030?ooo`000000000000L0oooo0`0000080?ooo`<00000203oool00`000000oooo
0?ooo`2W0?ooo`H0o`00903oool70000okD0oooo000010000000oooo0?ooo`0000060?ooo`<00000
1`3oool00`000000oooo0?ooo`02000000L0oooo00<000000?ooo`3oool0YP3oool60?l002H0oooo
1`000?nd0?ooo`00103oool00`000000oooo0?ooo`030?ooo`<000001P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0Y@3oool60?l002T0oooo1P00
0?nc0?ooo`00103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`2S0?ooo`L0o`00:`3oool70000ok40oooo00040?oo
o`030000003oool0oooo00`0oooo0P0000020?ooo`8000001`3oool300000:80oooo1`3o000]0?oo
o`L0003o/03oool000@0oooo00<000000?ooo`3oool0303oool5000000P0oooo00<000000?ooo`3o
ool0X@3oool60?l00340oooo1P000?n_0?ooo`00103oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0X03oool60?l003<0oooo1`000?n]0?ooo`00103o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0WP3o
ool70?l003D0oooo1`000?n/0?ooo`0000@000000?ooo`3oool00000403oool2000000X0oooo00<0
00000?ooo`3oool0W@3oool70?l003P0oooo1P000?n[0?ooo`0000<0oooo0000000000004`3oool3
000000L0oooo00<000000?ooo`3oool0W03oool60?l003/0oooo1P000?nZ0?ooo`00803oool00`00
0000oooo0?ooo`2J0?ooo`L0o`00?@3oool70000ojP0oooo000P0?ooo`030000003oool0oooo09T0
oooo1`3o00100?ooo`H0003oY`3oool00200oooo00<000000?ooo`3oool0V03oool60?l004<0oooo
1P000?nV0?ooo`00803oool00`000000oooo0?ooo`2F0?ooo`L0o`00A@3oool70000oj@0oooo000P
0?ooo`800000UP3oool70?l004L0oooo1`000?nS0?ooo`00803oool00`000000oooo0?ooo`2D0?oo
o`H0o`00B`3oool60000oj80oooo000P0?ooo`030000003oool0oooo0980oooo1`3o001=0?ooo`L0
003oX03oool00200oooo00<000000?ooo`3oool0T@3oool70?l004l0oooo1`000?nO0?ooo`00803o
ool00`000000oooo0?ooo`2@0?ooo`H0o`00D`3oool60000oih0oooo000P0?ooo`030000003oool0
oooo08h0oooo1`3o001E0?ooo`L0003oW03oool00200oooo00<000000?ooo`3oool0S@3oool70?l0
05L0oooo1`000?nK0?ooo`00803oool00`000000oooo0?ooo`2<0?ooo`H0o`00F`3oool70000oiT0
oooo000P0?ooo`030000003oool0oooo08X0oooo1`3o001M0?ooo`L0003oV03oool00200oooo00<0
00000?ooo`3oool0R@3oool70?l005l0oooo1`000?nG0?ooo`00803oool00`000000oooo0?ooo`28
0?ooo`H0o`00H`3oool70000oiD0oooo000P0?ooo`800000Q`3oool70?l006D0oooo1`000?nD0?oo
o`00803oool00`000000oooo0?ooo`250?ooo`L0o`00J03oool70000oi80oooo000P0?ooo`030000
003oool0oooo08@0oooo1P3o001[0?ooo`L0003oT@3oool00200oooo00<000000?ooo`3oool0PP3o
ool70?l006h0oooo1P000?n@0?ooo`00803oool00`000000oooo0?ooo`210?ooo`L0o`00L03oool7
0000ohh0oooo000P0?ooo`030000003oool0oooo0800oooo1P3o001c0?ooo`L0003oS@3oool00200
oooo00<000000?ooo`3oool0OP3oool70?l007H0oooo1`000?n;0?ooo`00803oool00`000000oooo
0?ooo`1m0?ooo`L0o`00N03oool70000ohX0oooo000P0?ooo`030000003oool0oooo07`0oooo1P3o
001l0?ooo`H0003oR@3oool00200oooo00<000000?ooo`3oool0NP3oool70?l007h0oooo1`000?n7
0?ooo`00803oool2000007X0oooo1`3o00200?ooo`L0003oQP3oool00200oooo00<000000?ooo`3o
ool0M`3oool70?l008@0oooo1P000?n50?ooo`00803oool00`000000oooo0?ooo`1f0?ooo`L0o`00
QP3oool70000oh<0oooo000P0?ooo`030000003oool0oooo07D0oooo1P3o00290?ooo`L0003oPP3o
ool00200oooo00<000000?ooo`3oool0L`3oool70?l008`0oooo1P000?n10?ooo`00803oool00`00
0000oooo0?ooo`1b0?ooo`L0o`00SP3oool70000ogl0oooo000P0?ooo`030000003oool0oooo0700
oooo1`3o002A0?ooo`L0003oOP3oool000030?ooo`000000000000L0oooo0`0000070?ooo`@00000
203oool00`000000oooo0?ooo`1_0?ooo`L0o`00U03oool60000ogd0oooo000010000000oooo0?oo
o`0000060?ooo`<000001P3oool200000080oooo0P0000070?ooo`030000003oool0oooo06d0oooo
1`3o002G0?ooo`L0003oN`3oool000@0oooo00<000000?ooo`3oool00`3oool3000000H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06`0oooo1`3o
002I0?ooo`L0003oNP3oool000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0JP3oool80?l009`0oooo1`000?mh
0?ooo`00103oool00`000000oooo0?ooo`0=0?ooo`D000001`3oool3000006T0oooo1`3o002O0?oo
o`P0003oMP3oool000@0oooo00<000000?ooo`3oool03@3oool4000000P0oooo00<000000?ooo`3o
ool0I`3oool70?l00:80oooo20000?me0?ooo`00103oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1U0?ooo`P0o`00
Y@3oool80000og<0oooo00040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06@0oooo1`3o002Y0?ooo`P0003oL@3o
ool000040000003oool0oooo000000l0oooo0P0000020?ooo`8000001`3oool00`000000oooo0?oo
o`1R0?ooo`P0o`00[03oool80000ofl0oooo00000`3oool000000000000A0?ooo`@00000203oool0
0`000000oooo0?ooo`1Q0?ooo`L0o`00[`3oool80000ofh0oooo000P0?ooo`030000003oool0oooo
05l0oooo1`3o002c0?ooo`P0003oK03oool00200oooo00<000000?ooo`3oool0G@3oool80?l00;H0
oooo20000?mZ0?ooo`00803oool00`000000oooo0?ooo`1L0?ooo`L0o`00^P3oool80000ofP0oooo
000P0?ooo`030000003oool0oooo05X0oooo203o002l0?ooo`P0003oI`3oool00200oooo0P00001I
0?ooo`P0o`00`03oool80000ofD0oooo000P0?ooo`030000003oool0oooo05H0oooo203o00340?oo
o`L0003oI03oool00200oooo00<000000?ooo`3oool0E@3oool80?l00<L0oooo1`000?mR0?ooo`00
803oool00`000000oooo0?ooo`1C0?ooo`P0o`00bP3oool80000of00oooo000P0?ooo`030000003o
ool0oooo0540oooo203o003>0?ooo`L0003oG`3oool00200oooo00<000000?ooo`3oool0D03oool8
0?l00=00oooo20000?mM0?ooo`00803oool00`000000oooo0?ooo`1>0?ooo`P0o`00e03oool70000
oe`0oooo000P0?ooo`030000003oool0oooo04`0oooo203o003H0?ooo`L0003oFP3oool00200oooo
00<000000?ooo`3oool0BP3oool80?l00=/0oooo20000?mH0?ooo`00803oool00`000000oooo0?oo
o`180?ooo`T0o`00gP3oool80000oeH0oooo000P0?ooo`800000AP3oool:0?l00>40oooo2@000?mD
0?ooo`00803oool00`000000oooo0?ooo`130?ooo`X0o`00i@3oool90000oe80oooo000P0?ooo`03
0000003oool0oooo0440oooo2P3o003Y0?ooo`T0003oD03oool00200oooo00<000000?ooo`3oool0
?`3oool:0?l00>d0oooo2@000?m>0?ooo`00803oool00`000000oooo0?ooo`0m0?ooo`T0o`00lP3o
ool90000od`0oooo000P0?ooo`030000003oool0oooo03X0oooo2P3o003f0?ooo`T0003oBP3oool0
0200oooo00<000000?ooo`3oool0>03oool:0?l00?X0oooo2P000?m70?ooo`00803oool00`000000
oooo0?ooo`0e0?ooo`/0o`00oP3oool:0000odD0oooo000P0?ooo`030000003oool0oooo03<0oooo
2P3o003o0?ooo`@0oooo2`000?m20?ooo`00803oool00`000000oooo0?ooo`0a0?ooo`X0o`00o`3o
ool80?ooo``0003o?`3oool00200oooo00<000000?ooo`3oool0;P3oool;0?l00?l0oooo3@3oool;
0000ocd0oooo000P0?ooo`800000;03oool;0?l00?l0oooo4P3oool<0000ocX0oooo000P0?ooo`03
0000003oool0oooo02P0oooo303o003o0?oooaL0oooo3@000?lf0?ooo`00803oool00`000000oooo
0?ooo`0U0?ooo``0o`00o`3ooolM0?ooo`h0003o<P3oool00200oooo00<000000?ooo`3oool08@3o
ool>0?l00?l0oooo8@3oool?0000obl0oooo000P0?ooo`030000003oool0oooo01h0oooo3P3o003o
0?ooobL0oooo3P000?l]0?ooo`00803oool00`000000oooo0?ooo`0J0?ooo`h0o`00o`3oool_0?oo
o`d0003o:P3oool00200oooo00<000000?ooo`3oool05@3oool@0?l00?l0oooo=P3ooolA0000ob80
oooo000D0?ooo`D000001`3oool00`000000oooo0?ooo`0A0?oooa40o`00o`3oooll0?oooa80003o
7P3oool001H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?oooaL0o`00o`3o
oom10?oooaP0003o5P3oool001H0oooo00<000000?ooo`3oool01@3ooolO0?l00?l0ooooB@3ooolP
0000o`/0oooo000F0?ooo`030000003oool0oooo00D0oooo6`3o003o0?oooeD0oooo60000?l;0?oo
o`005P3oool00`000000oooo0?ooo`050?oooaL0o`00o`3ooomM0?oooa@0003o2`3oool001H0oooo
00<000000?ooo`3oool01@3oool>0?l00?l0ooooKP3oool<0000o`/0oooo000F0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0o`3ooon>0?ooo`005P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0?l0ooooSP3oool001@0oooo00<000000?ooo`0000002@3oool00`00
0000oooo0?ooo`3o0?ooohh0oooo000E0?ooo`8000002@3oool00`000000oooo0?ooo`3o0?ooohh0
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.08251, -0.206921, \
0.00385446, 0.0071606}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Element stiffness matrix ",
  Cell[BoxData[
      \(TraditionalForm\`K\_e\)]]
}], "Subtitle",
  FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(Table[
      d2\[Phi]dx2\_i = \[PartialD]\_\(\[Xi], \[Xi]\)\[Phi]\_i, {i, 
        4}]\)\)\)], "Input",
  FontSize->24],

Cell[BoxData[
    \({\(-\(6\/h\^2\)\) + \(12\ \[Xi]\)\/h\^3, \(2\ \[Xi]\)\/h\^2 - \(4\ \((1 \
- \[Xi]\/h)\)\)\/h, 
      6\/h\^2 - \(12\ \[Xi]\)\/h\^3, \(-\(2\/h\)\) + \(6\ \[Xi]\)\/h\^2}\)], \
"Output"],

Cell[BoxData[
    \(K\_e = 
      Table[\[Integral]\_0\%h\((\ 
                EE\ II\ \(d2\[Phi]dx2\_i\) 
                  d2\[Phi]dx2\_j\ )\) \[DifferentialD]\[Xi]\ , {i, 4}, {j, 
            4}] // Simplify\)], "Input",
  FontSize->24],

Cell[BoxData[
    \({{\(12\ EE\ II\)\/h\^3, \(6\ EE\ II\)\/h\^2, \(-\(\(12\ EE\ \
II\)\/h\^3\)\), \(6\ EE\ II\)\/h\^2}, {\(6\ EE\ II\)\/h\^2, \(4\ EE\ II\)\/h, \
\(-\(\(6\ EE\ II\)\/h\^2\)\), \(2\ EE\ II\)\/h}, {\(-\(\(12\ EE\ II\)\/h\^3\)\
\), \(-\(\(6\ EE\ II\)\/h\^2\)\), \(12\ EE\ II\)\/h\^3, \(-\(\(6\ EE\ II\)\/h\
\^2\)\)}, {\(6\ EE\ II\)\/h\^2, \(2\ EE\ II\)\/h, \(-\(\(6\ EE\ \
II\)\/h\^2\)\), \(4\ EE\ II\)\/h}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(K\_e\/\(2\ EE\ II\/h\^3\) // MatrixForm\)], "Input",
  FontSize->24],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"6", \(3\ h\), \(-6\), \(3\ h\)},
            {\(3\ h\), \(2\ h\^2\), \(\(-3\)\ h\), \(h\^2\)},
            {\(-6\), \(\(-3\)\ h\), "6", \(\(-3\)\ h\)},
            {\(3\ h\), \(h\^2\), \(\(-3\)\ h\), \(2\ h\^2\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
Stiffness matrix should be singular, independently of h, E, I\
\>", \
"Subtitle",
  FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[K\_e]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Element force vector", "Subtitle",
  FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
    \(PP = \ Table[P[i], {i, 4}]; 
    R\_e = \(\(-\(\[Integral]\_0\%h q\_0\ \[Phi]\ \ \[DifferentialD]\[Xi]\)\)\
\ \  + \ PP // Simplify\) // MatrixForm\)], "Input",
  FontSize->21],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(P[1] - \(h\ q\_0\)\/2\)},
            {\(P[2] - \(h\^2\ q\_0\)\/12\)},
            {\(P[3] - \(h\ q\_0\)\/2\)},
            {\(P[4] + \(h\^2\ q\_0\)\/12\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        Plus[ 
          P[ 1], 
          Times[ 
            Rational[ -1, 2], h, 
            Subscript[ q, 0]]], 
        Plus[ 
          P[ 2], 
          Times[ 
            Rational[ -1, 12], 
            Power[ h, 2], 
            Subscript[ q, 0]]], 
        Plus[ 
          P[ 3], 
          Times[ 
            Rational[ -1, 2], h, 
            Subscript[ q, 0]]], 
        Plus[ 
          P[ 4], 
          Times[ 
            Rational[ 1, 12], 
            Power[ h, 2], 
            Subscript[ q, 0]]]}]]], "Output"]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1600}, {0, 1200}},
CellGrouping->Manual,
WindowSize->{792, 858},
WindowMargins->{{Automatic, 207}, {Automatic, 95}},
Magnification->1.5,
StyleDefinitions -> "DemoText.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 111, 3, 193, "Input"],
Cell[1868, 56, 137, 5, 231, "Title"],

Cell[CellGroupData[{
Cell[2030, 65, 87, 1, 130, "Subtitle"],
Cell[2120, 68, 523, 12, 496, "Input"],

Cell[CellGroupData[{
Cell[2668, 84, 316, 6, 249, "Input"],
Cell[2987, 92, 46, 1, 69, "Output"],
Cell[3036, 95, 46, 1, 69, "Output"],
Cell[3085, 98, 46, 1, 69, "Output"],
Cell[3134, 101, 46, 1, 69, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3217, 107, 485, 11, 473, "Input"],
Cell[3705, 120, 29765, 745, 291, 6801, 457, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[33519, 871, 128, 5, 81, "Subtitle"],

Cell[CellGroupData[{
Cell[33672, 880, 149, 4, 137, "Input"],
Cell[33824, 886, 203, 4, 102, "Output"],
Cell[34030, 892, 239, 6, 365, "Input"],
Cell[34272, 900, 434, 6, 234, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34743, 911, 88, 2, 132, "Input"],
Cell[34834, 915, 407, 9, 150, "Output"]
}, Open  ]],
Cell[35256, 927, 107, 4, 130, "Subtitle"],

Cell[CellGroupData[{
Cell[35388, 935, 42, 1, 54, "Input"],
Cell[35433, 938, 35, 1, 69, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[35517, 945, 56, 1, 81, "Subtitle"],

Cell[CellGroupData[{
Cell[35598, 950, 196, 4, 268, "Input"],
Cell[35797, 956, 841, 30, 216, "Output"]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

