(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     19020,        677]*)
(*NotebookOutlinePosition[     20013,        707]*)
(*  CellTagsIndexPosition[     19969,        703]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["Formulation of finite element matrices for a \n2d \
elastic square element [-1,1]\[Cross][-1,1]",
  FontSize->36]], "Title",
  TextAlignment->Center,
  FontSize->24],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; Off[General::spell, General::spell1];\)], "Input",\

  CellOpen->False],

Cell[CellGroupData[{

Cell["Shape functions and derivatives", "Subtitle",
  FontSize->24],

Cell[BoxData[{
    \(\(\[Phi]\_1\  = \ \(1\/4\) \((1 + x)\)\ \((1 + 
              y)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Phi]\_2\  = \ \(1\/4\) \((1 - x)\)\ \((1 + 
              y)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Phi]\_3\  = \ \(1\/4\) \((1 - x)\)\ \((1 - 
              y)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Phi]\_4\  = \ \(1\/4\) \((1 + x)\)\ \((1 - 
              y)\);\)\), "\[IndentingNewLine]", 
    \(\(d\[Phi]1x\  = \ D[\[Phi]\_1, x];\)\), "\[IndentingNewLine]", 
    \(\(d\[Phi]1y\  = \ D[\[Phi]\_1, y];\)\), "\[IndentingNewLine]", 
    \(\(d\[Phi]2x\  = \ D[\[Phi]\_2, x];\)\), "\[IndentingNewLine]", 
    \(\(d\[Phi]2y\  = \ D[\[Phi]\_2, y];\)\), "\[IndentingNewLine]", 
    \(\(d\[Phi]3x\  = \ D[\[Phi]\_3, x];\)\), "\[IndentingNewLine]", 
    \(\(d\[Phi]3y\  = \ D[\[Phi]\_3, y];\)\), "\[IndentingNewLine]", 
    \(\(d\[Phi]4x\  = \ D[\[Phi]\_4, x];\)\), "\[IndentingNewLine]", 
    \(\(\(d\[Phi]4y\  = \ D[\[Phi]\_4, y];\)\(\[IndentingNewLine]\)
    \)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Element displacement interpolation matrix", "Subtitle",
  FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"H", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\[Phi]\_1\), "0", \(\[Phi]\_2\), "0", \(\[Phi]\_3\), 
                "0", \(\[Phi]\_4\), "0"},
              {"0", \(\[Phi]\_1\), "0", \(\[Phi]\_2\), "0", \(\[Phi]\_3\), 
                "0", \(\[Phi]\_4\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", \(MatrixForm[
      Transpose[H]]\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/4\ \((1 + x)\)\ \((1 + y)\)\), "0"},
            {"0", \(1\/4\ \((1 + x)\)\ \((1 + y)\)\)},
            {\(1\/4\ \((1 - x)\)\ \((1 + y)\)\), "0"},
            {"0", \(1\/4\ \((1 - x)\)\ \((1 + y)\)\)},
            {\(1\/4\ \((1 - x)\)\ \((1 - y)\)\), "0"},
            {"0", \(1\/4\ \((1 - x)\)\ \((1 - y)\)\)},
            {\(1\/4\ \((1 + x)\)\ \((1 - y)\)\), "0"},
            {"0", \(1\/4\ \((1 + x)\)\ \((1 - y)\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Element nodal displacement vector", "Subtitle",
  FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[U]\), "\[IndentingNewLine]", 
    \(\(UU\  = \ 
        Table[U\_\(i, a\), {a, 4}, {i, 2}] // 
          Flatten;\)\), "\[IndentingNewLine]", 
    \(MatrixForm[UU]\)}], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(U\_\(1, 1\)\)},
            {\(U\_\(2, 1\)\)},
            {\(U\_\(1, 2\)\)},
            {\(U\_\(2, 2\)\)},
            {\(U\_\(1, 3\)\)},
            {\(U\_\(2, 3\)\)},
            {\(U\_\(1, 4\)\)},
            {\(U\_\(2, 4\)\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        Subscript[ U, 1, 1], 
        Subscript[ U, 2, 1], 
        Subscript[ U, 1, 2], 
        Subscript[ U, 2, 2], 
        Subscript[ U, 1, 3], 
        Subscript[ U, 2, 3], 
        Subscript[ U, 1, 4], 
        Subscript[ U, 2, 4]}]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Element strain-operator matrix ", "Subtitle",
  FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"B", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"d\[Phi]1x", "0", "d\[Phi]2x", "0", "d\[Phi]3x", "0", 
                "d\[Phi]4x", "0"},
              {"0", "d\[Phi]1y", "0", "d\[Phi]2y", "0", "d\[Phi]3y", "0", 
                "d\[Phi]4y"},
              {"d\[Phi]1y", "d\[Phi]1x", "d\[Phi]2y", "d\[Phi]2x", 
                "d\[Phi]3y", "d\[Phi]3x", "d\[Phi]4y", "d\[Phi]4x"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", \(MatrixForm[
      B]\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(1 + y\)\/4\), "0", \(1\/4\ \((\(-1\) - y)\)\), 
              "0", \(1\/4\ \((\(-1\) + y)\)\), "0", \(\(1 - y\)\/4\), "0"},
            {"0", \(\(1 + x\)\/4\), "0", \(\(1 - x\)\/4\), 
              "0", \(1\/4\ \((\(-1\) + x)\)\), 
              "0", \(1\/4\ \((\(-1\) - x)\)\)},
            {\(\(1 + x\)\/4\), \(\(1 + y\)\/4\), \(\(1 - 
                    x\)\/4\), \(1\/4\ \((\(-1\) - y)\)\), \(1\/4\ \((\(-1\) + 
                    x)\)\), \(1\/4\ \((\(-1\) + y)\)\), \(1\/4\ \((\(-1\) - 
                    x)\)\), \(\(1 - y\)\/4\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute a few strain fields from given nodal displacements", "Subtitle",
  FontSize->24],

Cell["Nodal coordinates", "Subsubtitle",
  FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(XY\_1 = \ {1, 1};\)\), "\[IndentingNewLine]", 
    \(\(XY\_2 = \ {\(-1\), 1};\)\), "\[IndentingNewLine]", 
    \(\(XY\_3 = \ {\(-1\), \(-1\)};\)\), "\[IndentingNewLine]", 
    \(\(XY\_4 = \ {1, \(-1\)};\)\), "\[IndentingNewLine]", 
    \(XYn\  = \ Table[XY\_i, {i, 4}]\)}], "Input"],

Cell[BoxData[
    \({{1, 1}, {\(-1\), 1}, {\(-1\), \(-1\)}, {1, \(-1\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      append\ first\ node\ for\ plotting\ purposes\ \
*) \)\(\[IndentingNewLine]\)\(XYp\  = \ 
      Append[XYn, XYn[\([1]\)]]\)\)\)], "Input"],

Cell[BoxData[
    \({{1, 1}, {\(-1\), 1}, {\(-1\), \(-1\)}, {1, \(-1\)}, {1, 
        1}}\)], "Output"]
}, Open  ]],

Cell["Nodal displacements", "Subsubtitle",
  FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(a = 0.25;\)\), "\[IndentingNewLine]", 
    \(\(UV\_1 = \ a {1, 0};\)\), "\[IndentingNewLine]", 
    \(\(UV\_2 = \ a {1, 0};\)\), "\[IndentingNewLine]", 
    \(\(UV\_3 = \ a {2, 0};\)\), "\[IndentingNewLine]", 
    \(\(UV\_4 = \ a {0, \(-3\)};\)\), "\[IndentingNewLine]", 
    \(UVn\  = \ Table[UV\_i, {i, 4}]\)}], "Input"],

Cell[BoxData[
    \({{0.25`, 0}, {0.25`, 0}, {0.5`, 0}, {0, \(-0.75`\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      append\ first\ node\ for\ plotting\ purposes\ \
*) \)\(\[IndentingNewLine]\)\(UVp\  = \ 
      Append[UVn, UVn[\([1]\)]]\)\)\)], "Input"],

Cell[BoxData[
    \({{0.25`, 0}, {0.25`, 0}, {0.5`, 0}, {0, \(-0.75`\)}, {0.25`, 
        0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*Nodal\ displacements*) \)\(\[IndentingNewLine]\)\(U\  = \ 
      Flatten[UVn]\[IndentingNewLine] (*\ 
      deformed\ nodal\ coordinates\ *) \[IndentingNewLine]
    XYd\  = \ XYn\  + \ UVn\[IndentingNewLine] (*\ 
      displacement\ field\ *) \[IndentingNewLine]
    u\  = \ \(H . U // Simplify\) // Chop\)\)\)], "Input"],

Cell[BoxData[
    \({0.25`, 0, 0.25`, 0, 0.5`, 0, 0, \(-0.75`\)}\)], "Output"],

Cell[BoxData[
    \({{1.25`, 1}, {\(-0.75`\), 
        1}, {\(-0.5`\), \(-1\)}, {1, \(-1.75`\)}}\)], "Output"],

Cell[BoxData[
    \({\(\(0.25`\)\(\[InvisibleSpace]\)\) + x\ \((\(-0.125`\) + 0.125`\ y)\), 
      0.1875`\ \((1 + x)\)\ \((\(-1\) + y)\)}\)], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      strains\ *) \)\(\[IndentingNewLine]\)\(\[Epsilon]\  = \ \(B . U // 
          Simplify\) // Chop\)\)\)], "Input"],

Cell[BoxData[
    \({\(-0.125`\) + 0.125`\ y, \(\(0.1875`\)\(\[InvisibleSpace]\)\) + 
        0.1875`\ x, \(-0.1875`\) + 0.125`\ x + 0.1875`\ y}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      plot\ original\ and\ deformed\ shape\ of\ element\ *) \)\(Show[
        Graphics[{Thickness[0.01], RGBColor[1, 0, 0], Line[XYp], 
            RGBColor[0, 0, 1], Line[XYp + UVp]}, 
          AspectRatio \[Rule] Automatic, Axes \[Rule] True]];\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.22222 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.44709 0.42328 0.769841 0.42328 [
[.02381 .75734 -6 -9 ]
[.02381 .75734 6 0 ]
[.23545 .75734 -12 -9 ]
[.23545 .75734 12 0 ]
[.65873 .75734 -9 -9 ]
[.65873 .75734 9 0 ]
[.87037 .75734 -3 -9 ]
[.87037 .75734 3 0 ]
[.43459 .13492 -24 -4.5 ]
[.43459 .13492 0 4.5 ]
[.43459 .34656 -12 -4.5 ]
[.43459 .34656 0 4.5 ]
[.43459 .5582 -24 -4.5 ]
[.43459 .5582 0 4.5 ]
[.43459 .98148 -18 -4.5 ]
[.43459 .98148 0 4.5 ]
[.43459 1.19312 -6 -4.5 ]
[.43459 1.19312 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.22222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .76984 m
.02381 .77609 L
s
[(-1)] .02381 .75734 0 1 Mshowa
.23545 .76984 m
.23545 .77609 L
s
[(-0.5)] .23545 .75734 0 1 Mshowa
.65873 .76984 m
.65873 .77609 L
s
[(0.5)] .65873 .75734 0 1 Mshowa
.87037 .76984 m
.87037 .77609 L
s
[(1)] .87037 .75734 0 1 Mshowa
.125 Mabswid
.06614 .76984 m
.06614 .77359 L
s
.10847 .76984 m
.10847 .77359 L
s
.15079 .76984 m
.15079 .77359 L
s
.19312 .76984 m
.19312 .77359 L
s
.27778 .76984 m
.27778 .77359 L
s
.32011 .76984 m
.32011 .77359 L
s
.36243 .76984 m
.36243 .77359 L
s
.40476 .76984 m
.40476 .77359 L
s
.48942 .76984 m
.48942 .77359 L
s
.53175 .76984 m
.53175 .77359 L
s
.57407 .76984 m
.57407 .77359 L
s
.6164 .76984 m
.6164 .77359 L
s
.70106 .76984 m
.70106 .77359 L
s
.74339 .76984 m
.74339 .77359 L
s
.78571 .76984 m
.78571 .77359 L
s
.82804 .76984 m
.82804 .77359 L
s
.9127 .76984 m
.9127 .77359 L
s
.95503 .76984 m
.95503 .77359 L
s
.99735 .76984 m
.99735 .77359 L
s
.25 Mabswid
0 .76984 m
1 .76984 L
s
.44709 .13492 m
.45334 .13492 L
s
[(-1.5)] .43459 .13492 1 0 Mshowa
.44709 .34656 m
.45334 .34656 L
s
[(-1)] .43459 .34656 1 0 Mshowa
.44709 .5582 m
.45334 .5582 L
s
[(-0.5)] .43459 .5582 1 0 Mshowa
.44709 .98148 m
.45334 .98148 L
s
[(0.5)] .43459 .98148 1 0 Mshowa
.44709 1.19312 m
.45334 1.19312 L
s
[(1)] .43459 1.19312 1 0 Mshowa
.125 Mabswid
.44709 .17725 m
.45084 .17725 L
s
.44709 .21958 m
.45084 .21958 L
s
.44709 .2619 m
.45084 .2619 L
s
.44709 .30423 m
.45084 .30423 L
s
.44709 .38889 m
.45084 .38889 L
s
.44709 .43122 m
.45084 .43122 L
s
.44709 .47354 m
.45084 .47354 L
s
.44709 .51587 m
.45084 .51587 L
s
.44709 .60053 m
.45084 .60053 L
s
.44709 .64286 m
.45084 .64286 L
s
.44709 .68519 m
.45084 .68519 L
s
.44709 .72751 m
.45084 .72751 L
s
.44709 .81217 m
.45084 .81217 L
s
.44709 .8545 m
.45084 .8545 L
s
.44709 .89683 m
.45084 .89683 L
s
.44709 .93915 m
.45084 .93915 L
s
.44709 1.02381 m
.45084 1.02381 L
s
.44709 1.06614 m
.45084 1.06614 L
s
.44709 1.10847 m
.45084 1.10847 L
s
.44709 1.15079 m
.45084 1.15079 L
s
.44709 .09259 m
.45084 .09259 L
s
.44709 .05026 m
.45084 .05026 L
s
.44709 .00794 m
.45084 .00794 L
s
.25 Mabswid
.44709 0 m
.44709 1.22222 L
s
0 0 m
1 0 L
1 1.22222 L
0 1.22222 L
closepath
clip
newpath
1 0 0 r
.01 w
.87037 1.19312 m
.02381 1.19312 L
.02381 .34656 L
.87037 .34656 L
.87037 1.19312 L
s
0 0 1 r
.97619 1.19312 m
.12963 1.19312 L
.23545 .34656 L
.87037 .0291 L
.97619 1.19312 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235.625, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Elastic moduli (Plane strain)", "Subtitle",
  FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"CC", " ", "=", " ", 
        RowBox[{\(EE\/\((1 - \[Nu]\^2)\)\), 
          RowBox[{"(", GridBox[{
                {"1", "\[Nu]", "0"},
                {"\[Nu]", "1", "0"},
                {"0", "0", \(\((1 - \[Nu])\)\/2\)}
                }], ")"}]}]}], ";"}], "\[IndentingNewLine]", \(MatrixForm[
      CC]\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(EE\/\(1 - \[Nu]\^2\)\), \(\(EE\ \[Nu]\)\/\(1 - \[Nu]\^2\)\), 
              "0"},
            {\(\(EE\ \[Nu]\)\/\(1 - \[Nu]\^2\)\), \(EE\/\(1 - \[Nu]\^2\)\), 
              "0"},
            {"0", 
              "0", \(\(EE\ \((1 - \[Nu])\)\)\/\(2\ \((1 - \[Nu]\^2)\)\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(K\  = \ 
        Integrate[Transpose[B] . CC . B, {x, \(-1\), 1}, {y, \(-1\), 1}] // 
          Simplify;\)\), "\[IndentingNewLine]", 
    \(MatrixForm[K]\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(6\ \((\(-1\) + \
\[Nu]\^2)\)\)\), \(EE\/\(8 - 
                    8\ \[Nu]\)\), \(\(EE\ \((3 + \[Nu])\)\)\/\(12\ \((\(-1\) \
+ \[Nu]\^2)\)\)\), \(\(EE - 3\ EE\ \[Nu]\)\/\(\(-8\) + 
                    8\ \[Nu]\^2\)\), \(-\(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(12\ \
\((\(-1\) + \[Nu]\^2)\)\)\)\), \(EE\/\(\(-8\) + 
                    8\ \[Nu]\)\), \(\(EE\ \[Nu]\)\/\(6 - 
                    6\ \[Nu]\^2\)\), \(\(EE - 3\ EE\ \[Nu]\)\/\(8 - 
                    8\ \[Nu]\^2\)\)},
            {\(EE\/\(8 - 
                    8\ \[Nu]\)\), \(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(6\ \
\((\(-1\) + \[Nu]\^2)\)\)\), \(\(EE - 3\ EE\ \[Nu]\)\/\(8 - 
                    8\ \[Nu]\^2\)\), \(\(EE\ \[Nu]\)\/\(6 - 
                    6\ \[Nu]\^2\)\), \(EE\/\(\(-8\) + 
                    8\ \[Nu]\)\), \(-\(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(12\ \
\((\(-1\) + \[Nu]\^2)\)\)\)\), \(\(EE - 3\ EE\ \[Nu]\)\/\(\(-8\) + 
                    8\ \[Nu]\^2\)\), \(\(EE\ \((3 + \[Nu])\)\)\/\(12\ \((\(-1\
\) + \[Nu]\^2)\)\)\)},
            {\(\(EE\ \((3 + \[Nu])\)\)\/\(12\ \((\(-1\) + \[Nu]\^2)\)\)\), \(\
\(EE - 3\ EE\ \[Nu]\)\/\(8 - 
                    8\ \[Nu]\^2\)\), \(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(6\ \((\
\(-1\) + \[Nu]\^2)\)\)\), \(EE\/\(\(-8\) + 
                    8\ \[Nu]\)\), \(\(EE\ \[Nu]\)\/\(6 - 
                    6\ \[Nu]\^2\)\), \(\(EE - 3\ EE\ \[Nu]\)\/\(\(-8\) + 
                    8\ \[Nu]\^2\)\), \(-\(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(12\ \
\((\(-1\) + \[Nu]\^2)\)\)\)\), \(EE\/\(8 - 8\ \[Nu]\)\)},
            {\(\(EE - 3\ EE\ \[Nu]\)\/\(\(-8\) + 
                    8\ \[Nu]\^2\)\), \(\(EE\ \[Nu]\)\/\(6 - 
                    6\ \[Nu]\^2\)\), \(EE\/\(\(-8\) + 
                    8\ \[Nu]\)\), \(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(6\ \
\((\(-1\) + \[Nu]\^2)\)\)\), \(\(EE - 3\ EE\ \[Nu]\)\/\(8 - 
                    8\ \[Nu]\^2\)\), \(\(EE\ \((3 + \[Nu])\)\)\/\(12\ \((\(-1\
\) + \[Nu]\^2)\)\)\), \(EE\/\(8 - 
                    8\ \[Nu]\)\), \(-\(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(12\ \
\((\(-1\) + \[Nu]\^2)\)\)\)\)},
            {\(-\(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(12\ \((\(-1\) + \[Nu]\^2)\)\
\)\)\), \(EE\/\(\(-8\) + 8\ \[Nu]\)\), \(\(EE\ \[Nu]\)\/\(6 - 
                    6\ \[Nu]\^2\)\), \(\(EE - 3\ EE\ \[Nu]\)\/\(8 - 
                    
                    8\ \[Nu]\^2\)\), \(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(6\ \((\
\(-1\) + \[Nu]\^2)\)\)\), \(EE\/\(8 - 
                    8\ \[Nu]\)\), \(\(EE\ \((3 + \[Nu])\)\)\/\(12\ \((\(-1\) \
+ \[Nu]\^2)\)\)\), \(\(EE - 3\ EE\ \[Nu]\)\/\(\(-8\) + 8\ \[Nu]\^2\)\)},
            {\(EE\/\(\(-8\) + 
                    8\ \[Nu]\)\), \(-\(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(12\ \
\((\(-1\) + \[Nu]\^2)\)\)\)\), \(\(EE - 3\ EE\ \[Nu]\)\/\(\(-8\) + 
                    8\ \[Nu]\^2\)\), \(\(EE\ \((3 + \[Nu])\)\)\/\(12\ \((\(-1\
\) + \[Nu]\^2)\)\)\), \(EE\/\(8 - 
                    8\ \[Nu]\)\), \(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(6\ \
\((\(-1\) + \[Nu]\^2)\)\)\), \(\(EE - 3\ EE\ \[Nu]\)\/\(8 - 
                    8\ \[Nu]\^2\)\), \(\(EE\ \[Nu]\)\/\(6 - 6\ \[Nu]\^2\)\)},
            {\(\(EE\ \[Nu]\)\/\(6 - 6\ \[Nu]\^2\)\), \(\(EE - 
                    3\ EE\ \[Nu]\)\/\(\(-8\) + 
                    8\ \[Nu]\^2\)\), \(-\(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(12\ \
\((\(-1\) + \[Nu]\^2)\)\)\)\), \(EE\/\(8 - 
                    8\ \[Nu]\)\), \(\(EE\ \((3 + \[Nu])\)\)\/\(12\ \((\(-1\) \
+ \[Nu]\^2)\)\)\), \(\(EE - 3\ EE\ \[Nu]\)\/\(8 - 
                    8\ \[Nu]\^2\)\), \(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(6\ \((\
\(-1\) + \[Nu]\^2)\)\)\), \(EE\/\(\(-8\) + 8\ \[Nu]\)\)},
            {\(\(EE - 3\ EE\ \[Nu]\)\/\(8 - 
                    8\ \[Nu]\^2\)\), \(\(EE\ \((3 + \[Nu])\)\)\/\(12\ \((\(-1\
\) + \[Nu]\^2)\)\)\), \(EE\/\(8 - 
                    8\ \[Nu]\)\), \(-\(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(12\ \
\((\(-1\) + \[Nu]\^2)\)\)\)\), \(\(EE - 3\ EE\ \[Nu]\)\/\(\(-8\) + 
                    8\ \[Nu]\^2\)\), \(\(EE\ \[Nu]\)\/\(6 - 
                    6\ \[Nu]\^2\)\), \(EE\/\(\(-8\) + 
                    8\ \[Nu]\)\), \(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(6\ \
\((\(-1\) + \[Nu]\^2)\)\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*Det[K] // Simplify*) \)], "Input"]
}, Open  ]]
},
FrontEndVersion->"4.2 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{1231, 940},
WindowMargins->{{20, Automatic}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "rapa", \
"courses", "16.21", "2003", "lecture_notes", "U15"}, "linearsquare.nb.ps", \
CharacterEncoding -> "iso8859-1"],
"Magnification"->1},
StyleDefinitions -> "DemoText.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 189, 4, 140, "Title"],
Cell[1946, 57, 114, 3, 19, "Input",
  CellOpen->False],

Cell[CellGroupData[{
Cell[2085, 64, 67, 1, 47, "Subtitle"],
Cell[2155, 67, 1005, 17, 439, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3197, 89, 77, 1, 47, "Subtitle"],

Cell[CellGroupData[{
Cell[3299, 94, 423, 9, 91, "Input"],
Cell[3725, 105, 619, 13, 281, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4393, 124, 69, 1, 47, "Subtitle"],

Cell[CellGroupData[{
Cell[4487, 129, 204, 5, 89, "Input"],
Cell[4694, 136, 636, 20, 233, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5379, 162, 67, 1, 47, "Subtitle"],

Cell[CellGroupData[{
Cell[5471, 167, 533, 11, 119, "Input"],
Cell[6007, 180, 737, 14, 133, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6793, 200, 94, 1, 47, "Subtitle"],
Cell[6890, 203, 56, 1, 69, "Subsubtitle"],

Cell[CellGroupData[{
Cell[6971, 208, 305, 5, 134, "Input"],
Cell[7279, 215, 86, 1, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7402, 221, 173, 4, 65, "Input"],
Cell[7578, 227, 103, 2, 52, "Output"]
}, Open  ]],
Cell[7696, 232, 58, 1, 69, "Subsubtitle"],

Cell[CellGroupData[{
Cell[7779, 237, 345, 6, 157, "Input"],
Cell[8127, 245, 86, 1, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8250, 251, 173, 4, 65, "Input"],
Cell[8426, 257, 107, 2, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8570, 264, 348, 6, 157, "Input"],
Cell[8921, 272, 78, 1, 52, "Output"],
Cell[9002, 275, 110, 2, 52, "Output"],
Cell[9115, 279, 152, 2, 52, "Output"],

Cell[CellGroupData[{
Cell[9292, 285, 149, 3, 65, "Input"],
Cell[9444, 290, 158, 2, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9639, 297, 294, 5, 88, "Input"],
Cell[9936, 304, 3499, 248, 304, 3372, 244, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13496, 559, 65, 1, 47, "Subtitle"],

Cell[CellGroupData[{
Cell[13586, 564, 365, 9, 130, "Input"],
Cell[13954, 575, 468, 11, 133, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14459, 591, 191, 4, 65, "Input"],
Cell[14653, 597, 4279, 73, 305, "Output"]
}, Open  ]],
Cell[18947, 673, 57, 1, 42, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

