(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     51266,       2603]*)
(*NotebookOutlinePosition[     51932,       2626]*)
(*  CellTagsIndexPosition[     51888,       2622]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Formulation of finite element matrices for a 2d elastic \
isoparametric 4-node quadrilateral element - Eigenvalue analysis of stiffness \
matrix (energy modes)\
\>", "Title",
  FontSize->36],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; Off[General::spell, General::spell1];\)], "Input",\

  FontSize->36],

Cell[CellGroupData[{

Cell["Shape functions and derivatives", "Subtitle",
  FontSize->36],

Cell[BoxData[{
    \(\(\[Phi]\_1\  = \ \(1\/4\) \((1 + \[Xi]\_1)\)\ \((1 + \[Xi]\_2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Phi]\_2\  = \ \(1\/4\) \((1 - \[Xi]\_1)\)\ \((1 + \[Xi]\_2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Phi]\_3\  = \ \(1\/4\) \((1 - \[Xi]\_1)\)\ \((1 - \[Xi]\_2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Phi]\_4\  = \ \(1\/4\) \((1 + \[Xi]\_1)\)\ \((1 - \[Xi]\_2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(d\[Phi]1\[Xi]1\  = \ 
        D[\[Phi]\_1, \[Xi]\_1];\)\), "\[IndentingNewLine]", 
    \(\(d\[Phi]1\[Xi]2\  = \ 
        D[\[Phi]\_1, \[Xi]\_2];\)\), "\[IndentingNewLine]", 
    \(\(d\[Phi]2\[Xi]1\  = \ 
        D[\[Phi]\_2, \[Xi]\_1];\)\), "\[IndentingNewLine]", 
    \(\(d\[Phi]2\[Xi]2\  = \ 
        D[\[Phi]\_2, \[Xi]\_2];\)\), "\[IndentingNewLine]", 
    \(\(d\[Phi]3\[Xi]1\  = \ 
        D[\[Phi]\_3, \[Xi]\_1];\)\), "\[IndentingNewLine]", 
    \(\(d\[Phi]3\[Xi]2\  = \ 
        D[\[Phi]\_3, \[Xi]\_2];\)\), "\[IndentingNewLine]", 
    \(\(d\[Phi]4\[Xi]1\  = \ 
        D[\[Phi]\_4, \[Xi]\_1];\)\), "\[IndentingNewLine]", 
    \(\(d\[Phi]4\[Xi]2\  = \ D[\[Phi]\_4, \[Xi]\_2];\)\)}], "Input",
  FontSize->36]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(h\)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[BoxData[
    \(h\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Element displacement interpolation matrix", "Subtitle",
  FontSize->36],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"H", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\[Phi]\_1\), "0", \(\[Phi]\_2\), "0", \(\[Phi]\_3\), 
                "0", \(\[Phi]\_4\), "0"},
              {"0", \(\[Phi]\_1\), "0", \(\[Phi]\_2\), "0", \(\[Phi]\_3\), 
                "0", \(\[Phi]\_4\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", \(MatrixForm[
      Transpose[H]]\)}], "Input",
  FontSize->36],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/4\ \((1 + \[Xi]\_1)\)\ \((1 + \[Xi]\_2)\)\), "0"},
            {"0", \(1\/4\ \((1 + \[Xi]\_1)\)\ \((1 + \[Xi]\_2)\)\)},
            {\(1\/4\ \((1 - \[Xi]\_1)\)\ \((1 + \[Xi]\_2)\)\), "0"},
            {"0", \(1\/4\ \((1 - \[Xi]\_1)\)\ \((1 + \[Xi]\_2)\)\)},
            {\(1\/4\ \((1 - \[Xi]\_1)\)\ \((1 - \[Xi]\_2)\)\), "0"},
            {"0", \(1\/4\ \((1 - \[Xi]\_1)\)\ \((1 - \[Xi]\_2)\)\)},
            {\(1\/4\ \((1 + \[Xi]\_1)\)\ \((1 - \[Xi]\_2)\)\), "0"},
            {"0", \(1\/4\ \((1 + \[Xi]\_1)\)\ \((1 - \[Xi]\_2)\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Element nodal displacement vector and dispacement \
interpolation\
\>", "Subtitle",
  FontSize->36],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Un\  = \ Table[U\_\(a, i\), {a, 4}, {i, 2}] // Flatten\), "\n", 
    \(ue\  = \ H . Un // Simplify\)}], "Input",
  FontSize->36],

Cell[BoxData[
    \({U\_\(1, 1\), U\_\(1, 2\), U\_\(2, 1\), U\_\(2, 2\), U\_\(3, 1\), 
      U\_\(3, 2\), U\_\(4, 1\), U\_\(4, 2\)}\)], "Output"],

Cell[BoxData[
    \({1\/4\ \((\((1 + \[Xi]\_1)\)\ \((1 + \[Xi]\_2)\)\ U\_\(1, 1\) - \((\(-1\
\) + \[Xi]\_1)\)\ \((1 + \[Xi]\_2)\)\ U\_\(2, 1\) + \((\(-1\) + \[Xi]\_2)\)\ \
\((\((\(-1\) + \[Xi]\_1)\)\ U\_\(3, 1\) - \((1 + \[Xi]\_1)\)\ U\_\(4, 1\))\))\
\), 1\/4\ \((\((1 + \[Xi]\_1)\)\ \((1 + \[Xi]\_2)\)\ U\_\(1, 2\) - \((\(-1\) \
+ \[Xi]\_1)\)\ \((1 + \[Xi]\_2)\)\ U\_\(2, 2\) + \((\(-1\) + \[Xi]\_2)\)\ \((\
\((\(-1\) + \[Xi]\_1)\)\ U\_\(3, 2\) - \((1 + \[Xi]\_1)\)\ U\_\(4, 2\))\))\)}\
\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Nodal coordinates and element coordinates interpolation (mapping)\
\
\>", "Subtitle",
  FontSize->36],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Xn\  = \ 
      Table[X\_\(a, i\), {a, 4}, {i, 2}] // 
        Flatten\), "\[IndentingNewLine]", 
    \(xe\  = \ H . Xn\)}], "Input",
  FontSize->36],

Cell[BoxData[
    \({X\_\(1, 1\), X\_\(1, 2\), X\_\(2, 1\), X\_\(2, 2\), X\_\(3, 1\), 
      X\_\(3, 2\), X\_\(4, 1\), X\_\(4, 2\)}\)], "Output"],

Cell[BoxData[
    \({1\/4\ \((1 + \[Xi]\_1)\)\ \((1 + \[Xi]\_2)\)\ X\_\(1, 1\) + 
        1\/4\ \((1 - \[Xi]\_1)\)\ \((1 + \[Xi]\_2)\)\ X\_\(2, 1\) + 
        1\/4\ \((1 - \[Xi]\_1)\)\ \((1 - \[Xi]\_2)\)\ X\_\(3, 1\) + 
        1\/4\ \((1 + \[Xi]\_1)\)\ \((1 - \[Xi]\_2)\)\ X\_\(4, 1\), 
      1\/4\ \((1 + \[Xi]\_1)\)\ \((1 + \[Xi]\_2)\)\ X\_\(1, 2\) + 
        1\/4\ \((1 - \[Xi]\_1)\)\ \((1 + \[Xi]\_2)\)\ X\_\(2, 2\) + 
        1\/4\ \((1 - \[Xi]\_1)\)\ \((1 - \[Xi]\_2)\)\ X\_\(3, 2\) + 
        1\/4\ \((1 + \[Xi]\_1)\)\ \((1 - \[Xi]\_2)\)\ X\_\(4, 2\)}\)], \
"Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Jacobian", "Subtitle",
  FontSize->36],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"J", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\[PartialD]\_\(\[Xi]\_1\)xe[\([1]\)]\), \(\[PartialD]\_\(\
\[Xi]\_1\)xe[\([2]\)]\)},
              {\(\[PartialD]\_\(\[Xi]\_2\)xe[\([1]\)]\), \(\[PartialD]\_\(\
\[Xi]\_2\)xe[\([2]\)]\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", \(MatrixForm[
      Simplify[Expand[J]]]\)}], "Input",
  FontSize->36],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/4\ \((\((1 + \[Xi]\_2)\)\ X\_\(1, 1\) - \((1 + \[Xi]\_2)\)\ \
X\_\(2, 1\) + \((\(-1\) + \[Xi]\_2)\)\ \((X\_\(3, 1\) - 
                          X\_\(4, 1\))\))\)\), \(1\/4\ \((\((1 + \[Xi]\_2)\)\ \
X\_\(1, 2\) - \((1 + \[Xi]\_2)\)\ X\_\(2, 2\) + \((\(-1\) + \[Xi]\_2)\)\ \((X\
\_\(3, 2\) - X\_\(4, 2\))\))\)\)},
            {\(1\/4\ \((\((1 + \[Xi]\_1)\)\ X\_\(1, 1\) + 
                    X\_\(2, 1\) - \[Xi]\_1\ X\_\(2, 1\) - 
                    X\_\(3, 1\) + \[Xi]\_1\ X\_\(3, 1\) - 
                    X\_\(4, 1\) - \[Xi]\_1\ X\_\(4, 1\))\)\), \(1\/4\ \((\((1 \
+ \[Xi]\_1)\)\ X\_\(1, 2\) + X\_\(2, 2\) - \[Xi]\_1\ X\_\(2, 2\) - 
                    X\_\(3, 2\) + \[Xi]\_1\ X\_\(3, 2\) - 
                    X\_\(4, 2\) - \[Xi]\_1\ X\_\(4, 2\))\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(Jinv\ \  = \ 
        Inverse[J] // Simplify;\), "\[IndentingNewLine]", \(detJ\  = \ 
      Det[J] // Simplify\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"A", " ", "=", " ", 
        RowBox[{\(1\/detJ\), 
          RowBox[{"(", GridBox[{
                {\(\(J[\([2]\)]\)[\([2]\)]\), \(-\(J[\([1]\)]\)[\([2]\)]\), 
                  "0", "0"},
                {"0", 
                  "0", \(-\(J[\([2]\)]\)[\([1]\)]\), \
\(\(J[\([1]\)]\)[\([1]\)]\)},
                {\(-\(J[\([2]\)]\)[\([1]\)]\), \(\(J[\([1]\)]\)[\([1]\)]\), \
\(\(J[\([2]\)]\)[\([2]\)]\), \(-\(J[\([1]\)]\)[\([2]\)]\)}
                }], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{"G", " ", "=", " ", 
      RowBox[{"(", GridBox[{
            {"d\[Phi]1\[Xi]1", "0", "d\[Phi]2\[Xi]1", "0", "d\[Phi]3\[Xi]1", 
              "0", "d\[Phi]4\[Xi]1", "0"},
            {"d\[Phi]1\[Xi]2", "0", "d\[Phi]2\[Xi]2", "0", "d\[Phi]3\[Xi]2", 
              "0", "d\[Phi]4\[Xi]2", "0"},
            {"0", "d\[Phi]1\[Xi]1", "0", "d\[Phi]2\[Xi]1", "0", 
              "d\[Phi]3\[Xi]1", "0", "d\[Phi]4\[Xi]1"},
            {"0", "d\[Phi]1\[Xi]2", "0", "d\[Phi]2\[Xi]2", "0", 
              "d\[Phi]3\[Xi]2", "0", "d\[Phi]4\[Xi]2"}
            }], ")"}]}]}], "Input",
  FontSize->36],

Cell[BoxData[
    \(1\/8\ \((\(-X\_\(2, 2\)\)\ X\_\(3, 1\) + \[Xi]\_1\ X\_\(2, 2\)\ X\_\(3, \
1\) + X\_\(2, 1\)\ X\_\(3, 2\) - \[Xi]\_1\ X\_\(2, 1\)\ X\_\(3, 2\) - \
\[Xi]\_1\ X\_\(2, 2\)\ X\_\(4, 1\) - \[Xi]\_2\ X\_\(2, 2\)\ X\_\(4, 1\) - 
          X\_\(3, 2\)\ X\_\(4, 1\) + \[Xi]\_2\ X\_\(3, 2\)\ X\_\(4, 1\) + 
          X\_\(1, 2\)\ \((\(-\((1 + \[Xi]\_2)\)\)\ X\_\(2, 1\) + \[Xi]\_2\ \
X\_\(3, 1\) + X\_\(4, 1\) + \[Xi]\_1\ \((\(-X\_\(3, 1\)\) + 
                      X\_\(4, 1\))\))\) + \[Xi]\_1\ X\_\(2, 1\)\ X\_\(4, 2\) \
+ \[Xi]\_2\ X\_\(2, 1\)\ X\_\(4, 2\) + 
          X\_\(3, 1\)\ X\_\(4, 2\) - \[Xi]\_2\ X\_\(3, 1\)\ X\_\(4, 2\) + 
          X\_\(1, 1\)\ \((\((1 + \[Xi]\_2)\)\ X\_\(2, 2\) + \[Xi]\_1\ X\_\(3, \
2\) - \[Xi]\_2\ X\_\(3, 2\) - 
                X\_\(4, 2\) - \[Xi]\_1\ X\_\(4, 2\))\))\)\)], "Output"],

Cell[BoxData[
    \({{1\/4\ \((1 + \[Xi]\_2)\), 0, 1\/4\ \((\(-1\) - \[Xi]\_2)\), 0, 
        1\/4\ \((\(-1\) + \[Xi]\_2)\), 0, 1\/4\ \((1 - \[Xi]\_2)\), 
        0}, {1\/4\ \((1 + \[Xi]\_1)\), 0, 1\/4\ \((1 - \[Xi]\_1)\), 0, 
        1\/4\ \((\(-1\) + \[Xi]\_1)\), 0, 1\/4\ \((\(-1\) - \[Xi]\_1)\), 
        0}, {0, 1\/4\ \((1 + \[Xi]\_2)\), 0, 1\/4\ \((\(-1\) - \[Xi]\_2)\), 
        0, 1\/4\ \((\(-1\) + \[Xi]\_2)\), 0, 1\/4\ \((1 - \[Xi]\_2)\)}, {0, 
        1\/4\ \((1 + \[Xi]\_1)\), 0, 1\/4\ \((1 - \[Xi]\_1)\), 0, 
        1\/4\ \((\(-1\) + \[Xi]\_1)\), 0, 
        1\/4\ \((\(-1\) - \[Xi]\_1)\)}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Element strain-operator matrix ", "Subtitle",
  FontSize->36],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(B\  = \ A . G // Simplify;\)\), "\[IndentingNewLine]", 
    \(Dimensions[B]\)}], "Input",
  FontSize->36],

Cell[BoxData[
    \({3, 8}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(values\  = \ {X\_\(1, 1\) \[Rule] 1, \ X\_\(1, 2\) \[Rule] 1, \ 
        X\_\(2, 1\) \[Rule] \(-2\), \ X\_\(2, 2\) \[Rule] 1, \ 
        X\_\(3, 1\) \[Rule] \(-1\), \ X\_\(3, 2\) \[Rule] \(-1\), \ 
        X\_\(4, 1\) \[Rule] 1, \ 
        X\_\(4, 2\) \[Rule] \(-1\)}\), "\[IndentingNewLine]", 
    \(\(J\  /. \ values\  // \ Simplify\) // 
      MatrixForm\), "\[IndentingNewLine]", 
    \(\(B\  /. \ values // Simplify\) // MatrixForm\)}], "Input",
  FontSize->36],

Cell[BoxData[
    \({X\_\(1, 1\) \[Rule] 1, X\_\(1, 2\) \[Rule] 1, 
      X\_\(2, 1\) \[Rule] \(-2\), X\_\(2, 2\) \[Rule] 1, 
      X\_\(3, 1\) \[Rule] \(-1\), X\_\(3, 2\) \[Rule] \(-1\), 
      X\_\(4, 1\) \[Rule] 1, X\_\(4, 2\) \[Rule] \(-1\)}\)], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/4\ \((5 + \[Xi]\_2)\)\), "0"},
            {\(1\/4\ \((\(-1\) + \[Xi]\_1)\)\), "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(1 + \[Xi]\_2\)\/\(5 + \[Xi]\_2\)\), 
              "0", \(-\(\(1 + \[Xi]\_2\)\/\(5 + \[Xi]\_2\)\)\), 
              "0", \(\(\(-1\) + \[Xi]\_2\)\/\(5 + \[Xi]\_2\)\), 
              "0", \(\(1 - \[Xi]\_2\)\/\(5 + \[Xi]\_2\)\), "0"},
            {"0", \(\(3 + 2\ \[Xi]\_1 + \[Xi]\_2\)\/\(10 + 2\ \[Xi]\_2\)\), 
              "0", \(\(1 - \[Xi]\_1\)\/\(5 + \[Xi]\_2\)\), 
              "0", \(\(3\ \((\(-1\) + \[Xi]\_1)\)\)\/\(2\ \((5 + \
\[Xi]\_2)\)\)\), 
              "0", \(-\(\(2 + 
                      3\ \[Xi]\_1 + \[Xi]\_2\)\/\(2\ \((5 + \
\[Xi]\_2)\)\)\)\)},
            {\(\(3 + 2\ \[Xi]\_1 + \[Xi]\_2\)\/\(10 + 
                    2\ \[Xi]\_2\)\), \(\(1 + \[Xi]\_2\)\/\(5 + \[Xi]\_2\)\), \
\(\(1 - \[Xi]\_1\)\/\(5 + \[Xi]\_2\)\), \(-\(\(1 + \[Xi]\_2\)\/\(5 + \[Xi]\_2\
\)\)\), \(\(3\ \((\(-1\) + \[Xi]\_1)\)\)\/\(2\ \((5 + \[Xi]\_2)\)\)\), \
\(\(\(-1\) + \[Xi]\_2\)\/\(5 + \[Xi]\_2\)\), \(-\(\(2 + 
                      3\ \[Xi]\_1 + \[Xi]\_2\)\/\(2\ \((5 + \
\[Xi]\_2)\)\)\)\), \(\(1 - \[Xi]\_2\)\/\(5 + \[Xi]\_2\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Stiffness Matrix", "Subtitle",
  FontSize->36],

Cell[CellGroupData[{

Cell["Elastic moduli (Plane strain)", "Subtitle",
  FontSize->36],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CC", " ", "=", " ", 
      RowBox[{\(EE\/\((1 - \[Nu]\^2)\)\), 
        RowBox[{"(", GridBox[{
              {"1", "\[Nu]", "0"},
              {"\[Nu]", "1", "0"},
              {"0", "0", \(\((1 - \[Nu])\)\/2\)}
              }], ")"}]}]}]], "Input",
  FontSize->36],

Cell[BoxData[
    \({{EE\/\(1 - \[Nu]\^2\), \(EE\ \[Nu]\)\/\(1 - \[Nu]\^2\), 
        0}, {\(EE\ \[Nu]\)\/\(1 - \[Nu]\^2\), EE\/\(1 - \[Nu]\^2\), 0}, {0, 
        0, \(EE\ \((1 - \[Nu])\)\)\/\(2\ \((1 - \[Nu]\^2)\)\)}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(values\  = \ {X\_\(1, 1\) \[Rule] 1, \ X\_\(1, 2\) \[Rule] 1, \ 
        X\_\(2, 1\) \[Rule] \(-1\), \ X\_\(2, 2\) \[Rule] 1, \ 
        X\_\(3, 1\) \[Rule] \(-1\), \ X\_\(3, 2\) \[Rule] \(-1\), \ 
        X\_\(4, 1\) \[Rule] 1, \ 
        X\_\(4, 2\) \[Rule] \(-1\)}\), "\[IndentingNewLine]", 
    \(\(integrand\  = \ 
        detJ\ Transpose[B] . CC . B\ \  /. \ values // 
          Simplify;\)\), "\[IndentingNewLine]", 
    \(K\  = \ 
      Integrate[integrand\ , {\[Xi]\_1, \(-1\), 1}, {\[Xi]\_2, \(-1\), 1}] // 
        Simplify\)}], "Input",
  FontSize->36],

Cell[BoxData[
    \({X\_\(1, 1\) \[Rule] 1, X\_\(1, 2\) \[Rule] 1, 
      X\_\(2, 1\) \[Rule] \(-1\), X\_\(2, 2\) \[Rule] 1, 
      X\_\(3, 1\) \[Rule] \(-1\), X\_\(3, 2\) \[Rule] \(-1\), 
      X\_\(4, 1\) \[Rule] 1, X\_\(4, 2\) \[Rule] \(-1\)}\)], "Output"],

Cell[BoxData[
    \({{\(EE\ \((\(-3\) + \[Nu])\)\)\/\(6\ \((\(-1\) + \[Nu]\^2)\)\), 
        EE\/\(8 - 8\ \[Nu]\), \(EE\ \((3 + \[Nu])\)\)\/\(12\ \((\(-1\) + \
\[Nu]\^2)\)\), \(EE - 3\ EE\ \[Nu]\)\/\(\(-8\) + 8\ \[Nu]\^2\), \(-\(\(EE\ \
\((\(-3\) + \[Nu])\)\)\/\(12\ \((\(-1\) + \[Nu]\^2)\)\)\)\), 
        EE\/\(\(-8\) + 8\ \[Nu]\), \(EE\ \[Nu]\)\/\(6 - 6\ \[Nu]\^2\), \(EE - \
3\ EE\ \[Nu]\)\/\(8 - 8\ \[Nu]\^2\)}, {EE\/\(8 - 8\ \[Nu]\), \(EE\ \((\(-3\) \
+ \[Nu])\)\)\/\(6\ \((\(-1\) + \[Nu]\^2)\)\), \(EE - 3\ EE\ \[Nu]\)\/\(8 - 8\ \
\[Nu]\^2\), \(EE\ \[Nu]\)\/\(6 - 6\ \[Nu]\^2\), 
        EE\/\(\(-8\) + 8\ \[Nu]\), \(-\(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(12\ \
\((\(-1\) + \[Nu]\^2)\)\)\)\), \(EE - 3\ EE\ \[Nu]\)\/\(\(-8\) + 8\ \
\[Nu]\^2\), \(EE\ \((3 + \[Nu])\)\)\/\(12\ \((\(-1\) + \[Nu]\^2)\)\)}, {\(EE\ \
\((3 + \[Nu])\)\)\/\(12\ \((\(-1\) + \[Nu]\^2)\)\), \(EE - 3\ EE\ \
\[Nu]\)\/\(8 - 8\ \[Nu]\^2\), \(EE\ \((\(-3\) + \[Nu])\)\)\/\(6\ \((\(-1\) + \
\[Nu]\^2)\)\), 
        EE\/\(\(-8\) + 8\ \[Nu]\), \(EE\ \[Nu]\)\/\(6 - 6\ \[Nu]\^2\), \(EE - \
3\ EE\ \[Nu]\)\/\(\(-8\) + 8\ \[Nu]\^2\), \(-\(\(EE\ \((\(-3\) + \[Nu])\)\)\/\
\(12\ \((\(-1\) + \[Nu]\^2)\)\)\)\), 
        EE\/\(8 - 8\ \[Nu]\)}, {\(EE - 3\ EE\ \[Nu]\)\/\(\(-8\) + 8\ \[Nu]\^2\
\), \(EE\ \[Nu]\)\/\(6 - 6\ \[Nu]\^2\), 
        EE\/\(\(-8\) + 8\ \[Nu]\), \(EE\ \((\(-3\) + \[Nu])\)\)\/\(6\ \((\(-1\
\) + \[Nu]\^2)\)\), \(EE - 3\ EE\ \[Nu]\)\/\(8 - 8\ \[Nu]\^2\), \(EE\ \((3 + \
\[Nu])\)\)\/\(12\ \((\(-1\) + \[Nu]\^2)\)\), 
        EE\/\(8 - 8\ \[Nu]\), \(-\(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(12\ \
\((\(-1\) + \[Nu]\^2)\)\)\)\)}, {\(-\(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(12\ \((\
\(-1\) + \[Nu]\^2)\)\)\)\), 
        EE\/\(\(-8\) + 8\ \[Nu]\), \(EE\ \[Nu]\)\/\(6 - 6\ \[Nu]\^2\), \(EE - \
3\ EE\ \[Nu]\)\/\(8 - 8\ \[Nu]\^2\), \(EE\ \((\(-3\) + \[Nu])\)\)\/\(6\ \
\((\(-1\) + \[Nu]\^2)\)\), 
        EE\/\(8 - 8\ \[Nu]\), \(EE\ \((3 + \[Nu])\)\)\/\(12\ \((\(-1\) + \
\[Nu]\^2)\)\), \(EE - 3\ EE\ \[Nu]\)\/\(\(-8\) + 8\ \[Nu]\^2\)}, \
{EE\/\(\(-8\) + 8\ \[Nu]\), \(-\(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(12\ \
\((\(-1\) + \[Nu]\^2)\)\)\)\), \(EE - 3\ EE\ \[Nu]\)\/\(\(-8\) + 8\ \
\[Nu]\^2\), \(EE\ \((3 + \[Nu])\)\)\/\(12\ \((\(-1\) + \[Nu]\^2)\)\), 
        EE\/\(8 - 8\ \[Nu]\), \(EE\ \((\(-3\) + \[Nu])\)\)\/\(6\ \((\(-1\) + \
\[Nu]\^2)\)\), \(EE - 3\ EE\ \[Nu]\)\/\(8 - 8\ \[Nu]\^2\), \(EE\ \[Nu]\)\/\(6 \
- 6\ \[Nu]\^2\)}, {\(EE\ \[Nu]\)\/\(6 - 6\ \[Nu]\^2\), \(EE - 3\ EE\ \
\[Nu]\)\/\(\(-8\) + 8\ \[Nu]\^2\), \(-\(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(12\ \
\((\(-1\) + \[Nu]\^2)\)\)\)\), 
        EE\/\(8 - 8\ \[Nu]\), \(EE\ \((3 + \[Nu])\)\)\/\(12\ \((\(-1\) + \
\[Nu]\^2)\)\), \(EE - 3\ EE\ \[Nu]\)\/\(8 - 8\ \[Nu]\^2\), \(EE\ \((\(-3\) + \
\[Nu])\)\)\/\(6\ \((\(-1\) + \[Nu]\^2)\)\), 
        EE\/\(\(-8\) + 8\ \[Nu]\)}, {\(EE - 3\ EE\ \[Nu]\)\/\(8 - 8\ \[Nu]\^2\
\), \(EE\ \((3 + \[Nu])\)\)\/\(12\ \((\(-1\) + \[Nu]\^2)\)\), 
        EE\/\(8 - 8\ \[Nu]\), \(-\(\(EE\ \((\(-3\) + \[Nu])\)\)\/\(12\ \
\((\(-1\) + \[Nu]\^2)\)\)\)\), \(EE - 3\ EE\ \[Nu]\)\/\(\(-8\) + 8\ \
\[Nu]\^2\), \(EE\ \[Nu]\)\/\(6 - 6\ \[Nu]\^2\), 
        EE\/\(\(-8\) + 8\ \[Nu]\), \(EE\ \((\(-3\) + \[Nu])\)\)\/\(6\ \((\(-1\
\) + \[Nu]\^2)\)\)}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*Det[K] // Simplify*) \)], "Input",
  FontSize->36]
}, Closed]],

Cell[CellGroupData[{

Cell["Eigenvalue analysis of stiffness matrix", "Subtitle",
  FontSize->36],

Cell[CellGroupData[{

Cell[BoxData[{
    \(k\  = 
      K\/\(EE\/\((1 - \[Nu]\^2)\)\)\  /. \ \[Nu] \[Rule] 0.3 // 
        Simplify\), "\[IndentingNewLine]", 
    \(evalues\  = \ Eigenvalues[k]\), "\[IndentingNewLine]", 
    \(evectors\  = \ Eigenvectors[k]\)}], "Input",
  FontSize->36],

Cell[BoxData[
    \({{0.44999999999999996`, 
        0.1625`, \(-0.27499999999999997`\), \(-0.01250000000000001`\), \
\(-0.22499999999999998`\), \(-0.1625`\), 0.05`, 
        0.01250000000000001`}, {0.1625`, 0.44999999999999996`, 
        0.01250000000000001`, 
        0.05`, \(-0.1625`\), \(-0.22499999999999998`\), \
\(-0.01250000000000001`\), \(-0.27499999999999997`\)}, \
{\(-0.27499999999999997`\), 0.01250000000000001`, 
        0.44999999999999996`, \(-0.1625`\), 
        0.05`, \(-0.01250000000000001`\), \(-0.22499999999999998`\), 
        0.1625`}, {\(-0.01250000000000001`\), 0.05`, \(-0.1625`\), 
        0.44999999999999996`, 
        0.01250000000000001`, \(-0.27499999999999997`\), 
        0.1625`, \(-0.22499999999999998`\)}, {\(-0.22499999999999998`\), \
\(-0.1625`\), 0.05`, 0.01250000000000001`, 0.44999999999999996`, 
        0.1625`, \(-0.27499999999999997`\), \(-0.01250000000000001`\)}, \
{\(-0.1625`\), \(-0.22499999999999998`\), \(-0.01250000000000001`\), \
\(-0.27499999999999997`\), 0.1625`, 0.44999999999999996`, 
        0.01250000000000001`, 
        0.05`}, {0.05`, \(-0.01250000000000001`\), \(-0.22499999999999998`\), 
        0.1625`, \(-0.27499999999999997`\), 0.01250000000000001`, 
        0.44999999999999996`, \(-0.1625`\)}, {0.01250000000000001`, \
\(-0.27499999999999997`\), 
        0.1625`, \(-0.22499999999999998`\), \(-0.01250000000000001`\), 
        0.05`, \(-0.1625`\), 0.44999999999999996`}}\)], "Output"],

Cell[BoxData[
    \({1.2999999999999998`, 0.7000000000000002`, 0.6999999999999998`, 
      0.45000000000000007`, 
      0.44999999999999996`, \(-1.3388795687364547`*^-16\), 
      1.0847371641737624`*^-16, \(-7.182839392716468`*^-18\)}\)], "Output"],

Cell[BoxData[
    \({{\(-0.3535533905932737`\), \(-0.35355339059327384`\), 
        0.35355339059327384`, \(-0.3535533905932739`\), 0.35355339059327373`, 
        0.3535533905932737`, \(-0.35355339059327395`\), 
        0.3535533905932738`}, {\(-0.15593671501555595`\), \
\(-0.47506182851304424`\), \(-0.47506182851304496`\), 0.1559367150155565`, 
        0.1559367150155571`, 0.47506182851304446`, 
        0.4750618285130437`, \(-0.15593671501555642`\)}, \
{0.4750618285130444`, \(-0.1559367150155565`\), \(-0.15593671501555662`\), \
\(-0.4750618285130444`\), \(-0.47506182851304407`\), 0.1559367150155564`, 
        0.15593671501555628`, 
        0.4750618285130444`}, {\(-0.48581183365859765`\), \
\(-0.11826606562015686`\), 0.4858118336585971`, 
        0.11826606562015624`, \(-0.4858118336585974`\), \
\(-0.11826606562015572`\), 0.48581183365859837`, 
        0.1182660656201562`}, {\(-0.11826606562015612`\), 
        0.48581183365859754`, 
        0.11826606562015625`, \(-0.48581183365859765`\), \
\(-0.11826606562015624`\), 0.4858118336585976`, 
        0.1182660656201565`, \(-0.4858118336585977`\)}, \
{\(-0.38273162117388043`\), 
        0.43920367116504033`, \(-0.3827316211738804`\), \
\(-0.2537410087976552`\), 0.31021305878881505`, \(-0.2537410087976553`\), 
        0.3102130587888151`, 
        0.43920367116504017`}, {\(-0.3554321687258649`\), \
\(-0.34594895889511623`\), \(-0.3554321687258649`\), \
\(-0.41401334084519775`\), \(-0.2873677867757832`\), \
\(-0.41401334084519775`\), \(-0.28736778677578323`\), \(-0.34594895889511607`\
\)}, {0.3196630719811747`, \(-0.24983885421314386`\), 
        0.3196630719811747`, \(-0.3731064915765291`\), 
        0.44293070934456025`, \(-0.37310649157652914`\), 
        0.44293070934456025`, \(-0.2498388542131438`\)}}\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(U\_1[v_]\  := \ 
      Table[\(evectors[\([v]\)]\)[\([j]\)], \ {j, 1, 8, 
          2}]\), "\[IndentingNewLine]", 
    \(\ u1[v_]\  := \ 
      Flatten[{U\_1[v], \(U\_1[v]\)[\([1]\)]}]\), "\[IndentingNewLine]", 
    \(U\_2[v_]\  := \ 
      Table[\(evectors[\([v]\)]\)[\([j]\)], \ {j, 2, 8, 
          2}]\), "\[IndentingNewLine]", 
    \(u2[v_]\  := \ 
      Flatten[{U\_2[v], \(U\_2[v]\)[\([1]\)]}]\), "\[IndentingNewLine]", 
    \(Ut[v_]\  := \ {u1[v], \ u2[v]}\), "\[IndentingNewLine]", 
    \(U[v_]\  := \ Transpose[Ut[v]]\)}], "Input",
  FontSize->36],

Cell[CellGroupData[{

Cell[BoxData[{
    \(X\_1 = Table[Xn[\([j]\)] /. values, {j, 1, 8, 2}]; \ 
    x1\  = \ Flatten[{X\_1, X\_1[\([1]\)]}]\), "\[IndentingNewLine]", 
    \(X\_2 = Table[Xn[\([j]\)] /. values, {j, 2, 8, 2}]; \ 
    x2\  = \ Flatten[{X\_2, X\_2[\([1]\)]}]\), "\[IndentingNewLine]", 
    \(X\  = \ Transpose[{x1, x2}]\)}], "Input",
  FontSize->36],

Cell[BoxData[
    \({1, \(-1\), \(-1\), 1, 1}\)], "Output"],

Cell[BoxData[
    \({1, 1, \(-1\), \(-1\), 1}\)], "Output"],

Cell[BoxData[
    \({{1, 1}, {\(-1\), 1}, {\(-1\), \(-1\)}, {1, \(-1\)}, {1, 
        1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(b\  = \ B /. \ values\  // Simplify;\)\), "\[IndentingNewLine]", 
    \(\(b . evectors[\([8]\)] // Simplify\) // Chop\)}], "Input",
  FontSize->36],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plots\  = \ 
        Table[Show[
            Graphics[{Thickness[0.01], RGBColor[1, 0, 0], Line[X], 
                RGBColor[0, 0, 1], Line[X + U[j]]}, \ 
              AspectRatio \[Rule] Automatic, Axes \[Rule] True]], {j, 
            8}];\)\)], "Input",
  FontSize->36],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[.02381 .4875 -6 -9 ]
[.02381 .4875 6 0 ]
[.2619 .4875 -12 -9 ]
[.2619 .4875 12 0 ]
[.7381 .4875 -9 -9 ]
[.7381 .4875 9 0 ]
[.97619 .4875 -3 -9 ]
[.97619 .4875 3 0 ]
[.4875 .02381 -12 -4.5 ]
[.4875 .02381 0 4.5 ]
[.4875 .2619 -24 -4.5 ]
[.4875 .2619 0 4.5 ]
[.4875 .7381 -18 -4.5 ]
[.4875 .7381 0 4.5 ]
[.4875 .97619 -6 -4.5 ]
[.4875 .97619 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .5 m
.02381 .50625 L
s
[(-1)] .02381 .4875 0 1 Mshowa
.2619 .5 m
.2619 .50625 L
s
[(-0.5)] .2619 .4875 0 1 Mshowa
.7381 .5 m
.7381 .50625 L
s
[(0.5)] .7381 .4875 0 1 Mshowa
.97619 .5 m
.97619 .50625 L
s
[(1)] .97619 .4875 0 1 Mshowa
.125 Mabswid
.07143 .5 m
.07143 .50375 L
s
.11905 .5 m
.11905 .50375 L
s
.16667 .5 m
.16667 .50375 L
s
.21429 .5 m
.21429 .50375 L
s
.30952 .5 m
.30952 .50375 L
s
.35714 .5 m
.35714 .50375 L
s
.40476 .5 m
.40476 .50375 L
s
.45238 .5 m
.45238 .50375 L
s
.54762 .5 m
.54762 .50375 L
s
.59524 .5 m
.59524 .50375 L
s
.64286 .5 m
.64286 .50375 L
s
.69048 .5 m
.69048 .50375 L
s
.78571 .5 m
.78571 .50375 L
s
.83333 .5 m
.83333 .50375 L
s
.88095 .5 m
.88095 .50375 L
s
.92857 .5 m
.92857 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .02381 m
.50625 .02381 L
s
[(-1)] .4875 .02381 1 0 Mshowa
.5 .2619 m
.50625 .2619 L
s
[(-0.5)] .4875 .2619 1 0 Mshowa
.5 .7381 m
.50625 .7381 L
s
[(0.5)] .4875 .7381 1 0 Mshowa
.5 .97619 m
.50625 .97619 L
s
[(1)] .4875 .97619 1 0 Mshowa
.125 Mabswid
.5 .07143 m
.50375 .07143 L
s
.5 .11905 m
.50375 .11905 L
s
.5 .16667 m
.50375 .16667 L
s
.5 .21429 m
.50375 .21429 L
s
.5 .30952 m
.50375 .30952 L
s
.5 .35714 m
.50375 .35714 L
s
.5 .40476 m
.50375 .40476 L
s
.5 .45238 m
.50375 .45238 L
s
.5 .54762 m
.50375 .54762 L
s
.5 .59524 m
.50375 .59524 L
s
.5 .64286 m
.50375 .64286 L
s
.5 .69048 m
.50375 .69048 L
s
.5 .78571 m
.50375 .78571 L
s
.5 .83333 m
.50375 .83333 L
s
.5 .88095 m
.50375 .88095 L
s
.5 .92857 m
.50375 .92857 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.01 w
.97619 .97619 m
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
.97619 .97619 L
s
0 0 1 r
.80783 .80783 m
.19217 .80783 L
.19217 .19217 L
.80783 .19217 L
.80783 .80783 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .78365 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.322827 0.391827 0.322827 [
[.01576 .37933 -12 -9 ]
[.01576 .37933 12 0 ]
[.17717 .37933 -6 -9 ]
[.17717 .37933 6 0 ]
[.33859 .37933 -12 -9 ]
[.33859 .37933 12 0 ]
[.66141 .37933 -9 -9 ]
[.66141 .37933 9 0 ]
[.82283 .37933 -3 -9 ]
[.82283 .37933 3 0 ]
[.98424 .37933 -9 -9 ]
[.98424 .37933 9 0 ]
[.4875 .069 -12 -4.5 ]
[.4875 .069 0 4.5 ]
[.4875 .23041 -24 -4.5 ]
[.4875 .23041 0 4.5 ]
[.4875 .55324 -18 -4.5 ]
[.4875 .55324 0 4.5 ]
[.4875 .71465 -6 -4.5 ]
[.4875 .71465 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .78365 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01576 .39183 m
.01576 .39808 L
s
[(-1.5)] .01576 .37933 0 1 Mshowa
.17717 .39183 m
.17717 .39808 L
s
[(-1)] .17717 .37933 0 1 Mshowa
.33859 .39183 m
.33859 .39808 L
s
[(-0.5)] .33859 .37933 0 1 Mshowa
.66141 .39183 m
.66141 .39808 L
s
[(0.5)] .66141 .37933 0 1 Mshowa
.82283 .39183 m
.82283 .39808 L
s
[(1)] .82283 .37933 0 1 Mshowa
.98424 .39183 m
.98424 .39808 L
s
[(1.5)] .98424 .37933 0 1 Mshowa
.125 Mabswid
.04804 .39183 m
.04804 .39558 L
s
.08032 .39183 m
.08032 .39558 L
s
.11261 .39183 m
.11261 .39558 L
s
.14489 .39183 m
.14489 .39558 L
s
.20946 .39183 m
.20946 .39558 L
s
.24174 .39183 m
.24174 .39558 L
s
.27402 .39183 m
.27402 .39558 L
s
.3063 .39183 m
.3063 .39558 L
s
.37087 .39183 m
.37087 .39558 L
s
.40315 .39183 m
.40315 .39558 L
s
.43543 .39183 m
.43543 .39558 L
s
.46772 .39183 m
.46772 .39558 L
s
.53228 .39183 m
.53228 .39558 L
s
.56457 .39183 m
.56457 .39558 L
s
.59685 .39183 m
.59685 .39558 L
s
.62913 .39183 m
.62913 .39558 L
s
.6937 .39183 m
.6937 .39558 L
s
.72598 .39183 m
.72598 .39558 L
s
.75826 .39183 m
.75826 .39558 L
s
.79054 .39183 m
.79054 .39558 L
s
.85511 .39183 m
.85511 .39558 L
s
.88739 .39183 m
.88739 .39558 L
s
.91968 .39183 m
.91968 .39558 L
s
.95196 .39183 m
.95196 .39558 L
s
.25 Mabswid
0 .39183 m
1 .39183 L
s
.5 .069 m
.50625 .069 L
s
[(-1)] .4875 .069 1 0 Mshowa
.5 .23041 m
.50625 .23041 L
s
[(-0.5)] .4875 .23041 1 0 Mshowa
.5 .55324 m
.50625 .55324 L
s
[(0.5)] .4875 .55324 1 0 Mshowa
.5 .71465 m
.50625 .71465 L
s
[(1)] .4875 .71465 1 0 Mshowa
.125 Mabswid
.5 .10128 m
.50375 .10128 L
s
.5 .13356 m
.50375 .13356 L
s
.5 .16585 m
.50375 .16585 L
s
.5 .19813 m
.50375 .19813 L
s
.5 .2627 m
.50375 .2627 L
s
.5 .29498 m
.50375 .29498 L
s
.5 .32726 m
.50375 .32726 L
s
.5 .35954 m
.50375 .35954 L
s
.5 .42411 m
.50375 .42411 L
s
.5 .45639 m
.50375 .45639 L
s
.5 .48867 m
.50375 .48867 L
s
.5 .52096 m
.50375 .52096 L
s
.5 .58552 m
.50375 .58552 L
s
.5 .61781 m
.50375 .61781 L
s
.5 .65009 m
.50375 .65009 L
s
.5 .68237 m
.50375 .68237 L
s
.5 .03672 m
.50375 .03672 L
s
.5 .00443 m
.50375 .00443 L
s
.5 .74694 m
.50375 .74694 L
s
.5 .77922 m
.50375 .77922 L
s
.25 Mabswid
.5 0 m
.5 .78365 L
s
0 0 m
1 0 L
1 .78365 L
0 .78365 L
closepath
clip
newpath
1 0 0 r
.01 w
.82283 .71465 m
.17717 .71465 L
.17717 .069 L
.82283 .069 L
.82283 .71465 L
s
0 0 1 r
.77249 .56129 m
.02381 .76499 L
.22751 .22236 L
.97619 .01866 L
.77249 .56129 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 225.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .67794 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.322827 0.338969 0.322827 [
[.01576 .32647 -12 -9 ]
[.01576 .32647 12 0 ]
[.17717 .32647 -6 -9 ]
[.17717 .32647 6 0 ]
[.33859 .32647 -12 -9 ]
[.33859 .32647 12 0 ]
[.66141 .32647 -9 -9 ]
[.66141 .32647 9 0 ]
[.82283 .32647 -3 -9 ]
[.82283 .32647 3 0 ]
[.98424 .32647 -9 -9 ]
[.98424 .32647 9 0 ]
[.4875 .01614 -12 -4.5 ]
[.4875 .01614 0 4.5 ]
[.4875 .17756 -24 -4.5 ]
[.4875 .17756 0 4.5 ]
[.4875 .50038 -18 -4.5 ]
[.4875 .50038 0 4.5 ]
[.4875 .6618 -6 -4.5 ]
[.4875 .6618 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .67794 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01576 .33897 m
.01576 .34522 L
s
[(-1.5)] .01576 .32647 0 1 Mshowa
.17717 .33897 m
.17717 .34522 L
s
[(-1)] .17717 .32647 0 1 Mshowa
.33859 .33897 m
.33859 .34522 L
s
[(-0.5)] .33859 .32647 0 1 Mshowa
.66141 .33897 m
.66141 .34522 L
s
[(0.5)] .66141 .32647 0 1 Mshowa
.82283 .33897 m
.82283 .34522 L
s
[(1)] .82283 .32647 0 1 Mshowa
.98424 .33897 m
.98424 .34522 L
s
[(1.5)] .98424 .32647 0 1 Mshowa
.125 Mabswid
.04804 .33897 m
.04804 .34272 L
s
.08032 .33897 m
.08032 .34272 L
s
.11261 .33897 m
.11261 .34272 L
s
.14489 .33897 m
.14489 .34272 L
s
.20946 .33897 m
.20946 .34272 L
s
.24174 .33897 m
.24174 .34272 L
s
.27402 .33897 m
.27402 .34272 L
s
.3063 .33897 m
.3063 .34272 L
s
.37087 .33897 m
.37087 .34272 L
s
.40315 .33897 m
.40315 .34272 L
s
.43543 .33897 m
.43543 .34272 L
s
.46772 .33897 m
.46772 .34272 L
s
.53228 .33897 m
.53228 .34272 L
s
.56457 .33897 m
.56457 .34272 L
s
.59685 .33897 m
.59685 .34272 L
s
.62913 .33897 m
.62913 .34272 L
s
.6937 .33897 m
.6937 .34272 L
s
.72598 .33897 m
.72598 .34272 L
s
.75826 .33897 m
.75826 .34272 L
s
.79054 .33897 m
.79054 .34272 L
s
.85511 .33897 m
.85511 .34272 L
s
.88739 .33897 m
.88739 .34272 L
s
.91968 .33897 m
.91968 .34272 L
s
.95196 .33897 m
.95196 .34272 L
s
.25 Mabswid
0 .33897 m
1 .33897 L
s
.5 .01614 m
.50625 .01614 L
s
[(-1)] .4875 .01614 1 0 Mshowa
.5 .17756 m
.50625 .17756 L
s
[(-0.5)] .4875 .17756 1 0 Mshowa
.5 .50038 m
.50625 .50038 L
s
[(0.5)] .4875 .50038 1 0 Mshowa
.5 .6618 m
.50625 .6618 L
s
[(1)] .4875 .6618 1 0 Mshowa
.125 Mabswid
.5 .04842 m
.50375 .04842 L
s
.5 .08071 m
.50375 .08071 L
s
.5 .11299 m
.50375 .11299 L
s
.5 .14527 m
.50375 .14527 L
s
.5 .20984 m
.50375 .20984 L
s
.5 .24212 m
.50375 .24212 L
s
.5 .2744 m
.50375 .2744 L
s
.5 .30669 m
.50375 .30669 L
s
.5 .37125 m
.50375 .37125 L
s
.5 .40353 m
.50375 .40353 L
s
.5 .43582 m
.50375 .43582 L
s
.5 .4681 m
.50375 .4681 L
s
.5 .53267 m
.50375 .53267 L
s
.5 .56495 m
.50375 .56495 L
s
.5 .59723 m
.50375 .59723 L
s
.5 .62951 m
.50375 .62951 L
s
.25 Mabswid
.5 0 m
.5 .67794 L
s
0 0 m
1 0 L
1 .67794 L
0 .67794 L
closepath
clip
newpath
1 0 0 r
.01 w
.82283 .6618 m
.17717 .6618 L
.17717 .01614 L
.82283 .01614 L
.82283 .6618 L
s
0 0 1 r
.97619 .61146 m
.12683 .50843 L
.02381 .06648 L
.87317 .1695 L
.97619 .61146 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 195.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75263 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.320492 0.376315 0.320492 [
[.01926 .36381 -12 -9 ]
[.01926 .36381 12 0 ]
[.17951 .36381 -6 -9 ]
[.17951 .36381 6 0 ]
[.33975 .36381 -12 -9 ]
[.33975 .36381 12 0 ]
[.66025 .36381 -9 -9 ]
[.66025 .36381 9 0 ]
[.82049 .36381 -3 -9 ]
[.82049 .36381 3 0 ]
[.98074 .36381 -9 -9 ]
[.98074 .36381 9 0 ]
[.4875 .05582 -12 -4.5 ]
[.4875 .05582 0 4.5 ]
[.4875 .21607 -24 -4.5 ]
[.4875 .21607 0 4.5 ]
[.4875 .53656 -18 -4.5 ]
[.4875 .53656 0 4.5 ]
[.4875 .69681 -6 -4.5 ]
[.4875 .69681 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .75263 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01926 .37631 m
.01926 .38256 L
s
[(-1.5)] .01926 .36381 0 1 Mshowa
.17951 .37631 m
.17951 .38256 L
s
[(-1)] .17951 .36381 0 1 Mshowa
.33975 .37631 m
.33975 .38256 L
s
[(-0.5)] .33975 .36381 0 1 Mshowa
.66025 .37631 m
.66025 .38256 L
s
[(0.5)] .66025 .36381 0 1 Mshowa
.82049 .37631 m
.82049 .38256 L
s
[(1)] .82049 .36381 0 1 Mshowa
.98074 .37631 m
.98074 .38256 L
s
[(1.5)] .98074 .36381 0 1 Mshowa
.125 Mabswid
.05131 .37631 m
.05131 .38006 L
s
.08336 .37631 m
.08336 .38006 L
s
.11541 .37631 m
.11541 .38006 L
s
.14746 .37631 m
.14746 .38006 L
s
.21156 .37631 m
.21156 .38006 L
s
.24361 .37631 m
.24361 .38006 L
s
.27566 .37631 m
.27566 .38006 L
s
.3077 .37631 m
.3077 .38006 L
s
.3718 .37631 m
.3718 .38006 L
s
.40385 .37631 m
.40385 .38006 L
s
.4359 .37631 m
.4359 .38006 L
s
.46795 .37631 m
.46795 .38006 L
s
.53205 .37631 m
.53205 .38006 L
s
.5641 .37631 m
.5641 .38006 L
s
.59615 .37631 m
.59615 .38006 L
s
.6282 .37631 m
.6282 .38006 L
s
.6923 .37631 m
.6923 .38006 L
s
.72434 .37631 m
.72434 .38006 L
s
.75639 .37631 m
.75639 .38006 L
s
.78844 .37631 m
.78844 .38006 L
s
.85254 .37631 m
.85254 .38006 L
s
.88459 .37631 m
.88459 .38006 L
s
.91664 .37631 m
.91664 .38006 L
s
.94869 .37631 m
.94869 .38006 L
s
.25 Mabswid
0 .37631 m
1 .37631 L
s
.5 .05582 m
.50625 .05582 L
s
[(-1)] .4875 .05582 1 0 Mshowa
.5 .21607 m
.50625 .21607 L
s
[(-0.5)] .4875 .21607 1 0 Mshowa
.5 .53656 m
.50625 .53656 L
s
[(0.5)] .4875 .53656 1 0 Mshowa
.5 .69681 m
.50625 .69681 L
s
[(1)] .4875 .69681 1 0 Mshowa
.125 Mabswid
.5 .08787 m
.50375 .08787 L
s
.5 .11992 m
.50375 .11992 L
s
.5 .15197 m
.50375 .15197 L
s
.5 .18402 m
.50375 .18402 L
s
.5 .24812 m
.50375 .24812 L
s
.5 .28017 m
.50375 .28017 L
s
.5 .31222 m
.50375 .31222 L
s
.5 .34427 m
.50375 .34427 L
s
.5 .40836 m
.50375 .40836 L
s
.5 .44041 m
.50375 .44041 L
s
.5 .47246 m
.50375 .47246 L
s
.5 .50451 m
.50375 .50451 L
s
.5 .56861 m
.50375 .56861 L
s
.5 .60066 m
.50375 .60066 L
s
.5 .63271 m
.50375 .63271 L
s
.5 .66476 m
.50375 .66476 L
s
.5 .02377 m
.50375 .02377 L
s
.5 .72886 m
.50375 .72886 L
s
.25 Mabswid
.5 0 m
.5 .75263 L
s
0 0 m
1 0 L
1 .75263 L
0 .75263 L
closepath
clip
newpath
1 0 0 r
.01 w
.82049 .69681 m
.17951 .69681 L
.17951 .05582 L
.82049 .05582 L
.82049 .69681 L
s
0 0 1 r
.66479 .6589 m
.33521 .73471 L
.02381 .01792 L
.97619 .09373 L
.66479 .6589 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 216.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.32867 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.425829 0.664337 0.425829 [
[.07417 .65184 -6 -9 ]
[.07417 .65184 6 0 ]
[.28709 .65184 -12 -9 ]
[.28709 .65184 12 0 ]
[.71291 .65184 -9 -9 ]
[.71291 .65184 9 0 ]
[.92583 .65184 -3 -9 ]
[.92583 .65184 3 0 ]
[.4875 .02559 -24 -4.5 ]
[.4875 .02559 0 4.5 ]
[.4875 .23851 -12 -4.5 ]
[.4875 .23851 0 4.5 ]
[.4875 .45142 -24 -4.5 ]
[.4875 .45142 0 4.5 ]
[.4875 .87725 -18 -4.5 ]
[.4875 .87725 0 4.5 ]
[.4875 1.09017 -6 -4.5 ]
[.4875 1.09017 0 4.5 ]
[.4875 1.30308 -18 -4.5 ]
[.4875 1.30308 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.32867 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07417 .66434 m
.07417 .67059 L
s
[(-1)] .07417 .65184 0 1 Mshowa
.28709 .66434 m
.28709 .67059 L
s
[(-0.5)] .28709 .65184 0 1 Mshowa
.71291 .66434 m
.71291 .67059 L
s
[(0.5)] .71291 .65184 0 1 Mshowa
.92583 .66434 m
.92583 .67059 L
s
[(1)] .92583 .65184 0 1 Mshowa
.125 Mabswid
.11675 .66434 m
.11675 .66809 L
s
.15934 .66434 m
.15934 .66809 L
s
.20192 .66434 m
.20192 .66809 L
s
.2445 .66434 m
.2445 .66809 L
s
.32967 .66434 m
.32967 .66809 L
s
.37225 .66434 m
.37225 .66809 L
s
.41483 .66434 m
.41483 .66809 L
s
.45742 .66434 m
.45742 .66809 L
s
.54258 .66434 m
.54258 .66809 L
s
.58517 .66434 m
.58517 .66809 L
s
.62775 .66434 m
.62775 .66809 L
s
.67033 .66434 m
.67033 .66809 L
s
.7555 .66434 m
.7555 .66809 L
s
.79808 .66434 m
.79808 .66809 L
s
.84066 .66434 m
.84066 .66809 L
s
.88325 .66434 m
.88325 .66809 L
s
.03159 .66434 m
.03159 .66809 L
s
.96841 .66434 m
.96841 .66809 L
s
.25 Mabswid
0 .66434 m
1 .66434 L
s
.5 .02559 m
.50625 .02559 L
s
[(-1.5)] .4875 .02559 1 0 Mshowa
.5 .23851 m
.50625 .23851 L
s
[(-1)] .4875 .23851 1 0 Mshowa
.5 .45142 m
.50625 .45142 L
s
[(-0.5)] .4875 .45142 1 0 Mshowa
.5 .87725 m
.50625 .87725 L
s
[(0.5)] .4875 .87725 1 0 Mshowa
.5 1.09017 m
.50625 1.09017 L
s
[(1)] .4875 1.09017 1 0 Mshowa
.5 1.30308 m
.50625 1.30308 L
s
[(1.5)] .4875 1.30308 1 0 Mshowa
.125 Mabswid
.5 .06818 m
.50375 .06818 L
s
.5 .11076 m
.50375 .11076 L
s
.5 .15334 m
.50375 .15334 L
s
.5 .19593 m
.50375 .19593 L
s
.5 .28109 m
.50375 .28109 L
s
.5 .32367 m
.50375 .32367 L
s
.5 .36626 m
.50375 .36626 L
s
.5 .40884 m
.50375 .40884 L
s
.5 .49401 m
.50375 .49401 L
s
.5 .53659 m
.50375 .53659 L
s
.5 .57917 m
.50375 .57917 L
s
.5 .62175 m
.50375 .62175 L
s
.5 .70692 m
.50375 .70692 L
s
.5 .7495 m
.50375 .7495 L
s
.5 .79209 m
.50375 .79209 L
s
.5 .83467 m
.50375 .83467 L
s
.5 .91983 m
.50375 .91983 L
s
.5 .96242 m
.50375 .96242 L
s
.5 1.005 m
.50375 1.005 L
s
.5 1.04758 m
.50375 1.04758 L
s
.5 1.13275 m
.50375 1.13275 L
s
.5 1.17533 m
.50375 1.17533 L
s
.5 1.21792 m
.50375 1.21792 L
s
.5 1.2605 m
.50375 1.2605 L
s
.25 Mabswid
.5 0 m
.5 1.32867 L
s
0 0 m
1 0 L
1 1.32867 L
0 1.32867 L
closepath
clip
newpath
1 0 0 r
.01 w
.92583 1.09017 m
.07417 1.09017 L
.07417 .23851 L
.92583 .23851 L
.92583 1.09017 L
s
0 0 1 r
.87547 1.29704 m
.12453 .88329 L
.02381 .44538 L
.97619 .03164 L
.87547 1.29704 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216.75, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.512823 0.353658 0.467205 0.353658 [
[.15917 .4547 -6 -9 ]
[.15917 .4547 6 0 ]
[.33599 .4547 -12 -9 ]
[.33599 .4547 12 0 ]
[.68965 .4547 -9 -9 ]
[.68965 .4547 9 0 ]
[.86648 .4547 -3 -9 ]
[.86648 .4547 3 0 ]
[.50032 .11355 -12 -4.5 ]
[.50032 .11355 0 4.5 ]
[.50032 .29038 -24 -4.5 ]
[.50032 .29038 0 4.5 ]
[.50032 .64403 -18 -4.5 ]
[.50032 .64403 0 4.5 ]
[.50032 .82086 -6 -4.5 ]
[.50032 .82086 0 4.5 ]
[.50032 .99769 -18 -4.5 ]
[.50032 .99769 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15917 .4672 m
.15917 .47345 L
s
[(-1)] .15917 .4547 0 1 Mshowa
.33599 .4672 m
.33599 .47345 L
s
[(-0.5)] .33599 .4547 0 1 Mshowa
.68965 .4672 m
.68965 .47345 L
s
[(0.5)] .68965 .4547 0 1 Mshowa
.86648 .4672 m
.86648 .47345 L
s
[(1)] .86648 .4547 0 1 Mshowa
.125 Mabswid
.19453 .4672 m
.19453 .47095 L
s
.2299 .4672 m
.2299 .47095 L
s
.26526 .4672 m
.26526 .47095 L
s
.30063 .4672 m
.30063 .47095 L
s
.37136 .4672 m
.37136 .47095 L
s
.40673 .4672 m
.40673 .47095 L
s
.44209 .4672 m
.44209 .47095 L
s
.47746 .4672 m
.47746 .47095 L
s
.54819 .4672 m
.54819 .47095 L
s
.58355 .4672 m
.58355 .47095 L
s
.61892 .4672 m
.61892 .47095 L
s
.65429 .4672 m
.65429 .47095 L
s
.72502 .4672 m
.72502 .47095 L
s
.76038 .4672 m
.76038 .47095 L
s
.79575 .4672 m
.79575 .47095 L
s
.83112 .4672 m
.83112 .47095 L
s
.1238 .4672 m
.1238 .47095 L
s
.08843 .4672 m
.08843 .47095 L
s
.05307 .4672 m
.05307 .47095 L
s
.0177 .4672 m
.0177 .47095 L
s
.90185 .4672 m
.90185 .47095 L
s
.93721 .4672 m
.93721 .47095 L
s
.97258 .4672 m
.97258 .47095 L
s
.25 Mabswid
0 .4672 m
1 .4672 L
s
.51282 .11355 m
.51907 .11355 L
s
[(-1)] .50032 .11355 1 0 Mshowa
.51282 .29038 m
.51907 .29038 L
s
[(-0.5)] .50032 .29038 1 0 Mshowa
.51282 .64403 m
.51907 .64403 L
s
[(0.5)] .50032 .64403 1 0 Mshowa
.51282 .82086 m
.51907 .82086 L
s
[(1)] .50032 .82086 1 0 Mshowa
.51282 .99769 m
.51907 .99769 L
s
[(1.5)] .50032 .99769 1 0 Mshowa
.125 Mabswid
.51282 .14891 m
.51657 .14891 L
s
.51282 .18428 m
.51657 .18428 L
s
.51282 .21964 m
.51657 .21964 L
s
.51282 .25501 m
.51657 .25501 L
s
.51282 .32574 m
.51657 .32574 L
s
.51282 .36111 m
.51657 .36111 L
s
.51282 .39647 m
.51657 .39647 L
s
.51282 .43184 m
.51657 .43184 L
s
.51282 .50257 m
.51657 .50257 L
s
.51282 .53794 m
.51657 .53794 L
s
.51282 .5733 m
.51657 .5733 L
s
.51282 .60867 m
.51657 .60867 L
s
.51282 .6794 m
.51657 .6794 L
s
.51282 .71477 m
.51657 .71477 L
s
.51282 .75013 m
.51657 .75013 L
s
.51282 .7855 m
.51657 .7855 L
s
.51282 .85623 m
.51657 .85623 L
s
.51282 .89159 m
.51657 .89159 L
s
.51282 .92696 m
.51657 .92696 L
s
.51282 .96233 m
.51657 .96233 L
s
.51282 .07818 m
.51657 .07818 L
s
.51282 .04282 m
.51657 .04282 L
s
.51282 .00745 m
.51657 .00745 L
s
.25 Mabswid
.51282 0 m
.51282 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.01 w
.86648 .82086 m
.15917 .82086 L
.15917 .11355 L
.86648 .11355 L
.86648 .82086 L
s
0 0 1 r
.73113 .97619 m
.02381 .73113 L
.26887 .02381 L
.97619 .26887 L
.73113 .97619 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.02487 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.571857 0.404334 0.596135 0.404334 [
[.16752 .58364 -6 -9 ]
[.16752 .58364 6 0 ]
[.36969 .58364 -12 -9 ]
[.36969 .58364 12 0 ]
[.77402 .58364 -9 -9 ]
[.77402 .58364 9 0 ]
[.97619 .58364 -3 -9 ]
[.97619 .58364 3 0 ]
[.55936 .1918 -12 -4.5 ]
[.55936 .1918 0 4.5 ]
[.55936 .39397 -24 -4.5 ]
[.55936 .39397 0 4.5 ]
[.55936 .7983 -18 -4.5 ]
[.55936 .7983 0 4.5 ]
[.55936 1.00047 -6 -4.5 ]
[.55936 1.00047 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.02487 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16752 .59614 m
.16752 .60239 L
s
[(-1)] .16752 .58364 0 1 Mshowa
.36969 .59614 m
.36969 .60239 L
s
[(-0.5)] .36969 .58364 0 1 Mshowa
.77402 .59614 m
.77402 .60239 L
s
[(0.5)] .77402 .58364 0 1 Mshowa
.97619 .59614 m
.97619 .60239 L
s
[(1)] .97619 .58364 0 1 Mshowa
.125 Mabswid
.20796 .59614 m
.20796 .59989 L
s
.24839 .59614 m
.24839 .59989 L
s
.28882 .59614 m
.28882 .59989 L
s
.32926 .59614 m
.32926 .59989 L
s
.41012 .59614 m
.41012 .59989 L
s
.45056 .59614 m
.45056 .59989 L
s
.49099 .59614 m
.49099 .59989 L
s
.53142 .59614 m
.53142 .59989 L
s
.61229 .59614 m
.61229 .59989 L
s
.65272 .59614 m
.65272 .59989 L
s
.69316 .59614 m
.69316 .59989 L
s
.73359 .59614 m
.73359 .59989 L
s
.81446 .59614 m
.81446 .59989 L
s
.85489 .59614 m
.85489 .59989 L
s
.89532 .59614 m
.89532 .59989 L
s
.93576 .59614 m
.93576 .59989 L
s
.12709 .59614 m
.12709 .59989 L
s
.08666 .59614 m
.08666 .59989 L
s
.04622 .59614 m
.04622 .59989 L
s
.00579 .59614 m
.00579 .59989 L
s
.25 Mabswid
0 .59614 m
1 .59614 L
s
.57186 .1918 m
.57811 .1918 L
s
[(-1)] .55936 .1918 1 0 Mshowa
.57186 .39397 m
.57811 .39397 L
s
[(-0.5)] .55936 .39397 1 0 Mshowa
.57186 .7983 m
.57811 .7983 L
s
[(0.5)] .55936 .7983 1 0 Mshowa
.57186 1.00047 m
.57811 1.00047 L
s
[(1)] .55936 1.00047 1 0 Mshowa
.125 Mabswid
.57186 .23223 m
.57561 .23223 L
s
.57186 .27267 m
.57561 .27267 L
s
.57186 .3131 m
.57561 .3131 L
s
.57186 .35353 m
.57561 .35353 L
s
.57186 .4344 m
.57561 .4344 L
s
.57186 .47483 m
.57561 .47483 L
s
.57186 .51527 m
.57561 .51527 L
s
.57186 .5557 m
.57561 .5557 L
s
.57186 .63657 m
.57561 .63657 L
s
.57186 .677 m
.57561 .677 L
s
.57186 .71744 m
.57561 .71744 L
s
.57186 .75787 m
.57561 .75787 L
s
.57186 .83874 m
.57561 .83874 L
s
.57186 .87917 m
.57561 .87917 L
s
.57186 .9196 m
.57561 .9196 L
s
.57186 .96004 m
.57561 .96004 L
s
.57186 .15137 m
.57561 .15137 L
s
.57186 .11093 m
.57561 .11093 L
s
.57186 .0705 m
.57561 .0705 L
s
.57186 .03007 m
.57561 .03007 L
s
.25 Mabswid
.57186 0 m
.57186 1.02487 L
s
0 0 m
1 0 L
1 1.02487 L
0 1.02487 L
closepath
clip
newpath
1 0 0 r
.01 w
.97619 1.00047 m
.16752 1.00047 L
.16752 .1918 L
.97619 .1918 L
.97619 1.00047 L
s
0 0 1 r
.83248 .86059 m
.02381 .83307 L
.05133 .0244 L
.86 .05192 L
.83248 .86059 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{281, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .97142 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.413661 0.389852 0.558437 0.389852 [
[.02381 .54594 -6 -9 ]
[.02381 .54594 6 0 ]
[.21874 .54594 -12 -9 ]
[.21874 .54594 12 0 ]
[.60859 .54594 -9 -9 ]
[.60859 .54594 9 0 ]
[.80351 .54594 -3 -9 ]
[.80351 .54594 3 0 ]
[.99844 .54594 -9 -9 ]
[.99844 .54594 9 0 ]
[.40116 .16859 -12 -4.5 ]
[.40116 .16859 0 4.5 ]
[.40116 .36351 -24 -4.5 ]
[.40116 .36351 0 4.5 ]
[.40116 .75336 -18 -4.5 ]
[.40116 .75336 0 4.5 ]
[.40116 .94829 -6 -4.5 ]
[.40116 .94829 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .97142 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .55844 m
.02381 .56469 L
s
[(-1)] .02381 .54594 0 1 Mshowa
.21874 .55844 m
.21874 .56469 L
s
[(-0.5)] .21874 .54594 0 1 Mshowa
.60859 .55844 m
.60859 .56469 L
s
[(0.5)] .60859 .54594 0 1 Mshowa
.80351 .55844 m
.80351 .56469 L
s
[(1)] .80351 .54594 0 1 Mshowa
.99844 .55844 m
.99844 .56469 L
s
[(1.5)] .99844 .54594 0 1 Mshowa
.125 Mabswid
.06279 .55844 m
.06279 .56219 L
s
.10178 .55844 m
.10178 .56219 L
s
.14077 .55844 m
.14077 .56219 L
s
.17975 .55844 m
.17975 .56219 L
s
.25772 .55844 m
.25772 .56219 L
s
.29671 .55844 m
.29671 .56219 L
s
.33569 .55844 m
.33569 .56219 L
s
.37468 .55844 m
.37468 .56219 L
s
.45265 .55844 m
.45265 .56219 L
s
.49163 .55844 m
.49163 .56219 L
s
.53062 .55844 m
.53062 .56219 L
s
.5696 .55844 m
.5696 .56219 L
s
.64757 .55844 m
.64757 .56219 L
s
.68656 .55844 m
.68656 .56219 L
s
.72554 .55844 m
.72554 .56219 L
s
.76453 .55844 m
.76453 .56219 L
s
.8425 .55844 m
.8425 .56219 L
s
.88148 .55844 m
.88148 .56219 L
s
.92047 .55844 m
.92047 .56219 L
s
.95945 .55844 m
.95945 .56219 L
s
.25 Mabswid
0 .55844 m
1 .55844 L
s
.41366 .16859 m
.41991 .16859 L
s
[(-1)] .40116 .16859 1 0 Mshowa
.41366 .36351 m
.41991 .36351 L
s
[(-0.5)] .40116 .36351 1 0 Mshowa
.41366 .75336 m
.41991 .75336 L
s
[(0.5)] .40116 .75336 1 0 Mshowa
.41366 .94829 m
.41991 .94829 L
s
[(1)] .40116 .94829 1 0 Mshowa
.125 Mabswid
.41366 .20757 m
.41741 .20757 L
s
.41366 .24656 m
.41741 .24656 L
s
.41366 .28554 m
.41741 .28554 L
s
.41366 .32453 m
.41741 .32453 L
s
.41366 .4025 m
.41741 .4025 L
s
.41366 .44148 m
.41741 .44148 L
s
.41366 .48047 m
.41741 .48047 L
s
.41366 .51945 m
.41741 .51945 L
s
.41366 .59742 m
.41741 .59742 L
s
.41366 .63641 m
.41741 .63641 L
s
.41366 .67539 m
.41741 .67539 L
s
.41366 .71438 m
.41741 .71438 L
s
.41366 .79235 m
.41741 .79235 L
s
.41366 .83133 m
.41741 .83133 L
s
.41366 .87032 m
.41741 .87032 L
s
.41366 .9093 m
.41741 .9093 L
s
.41366 .1296 m
.41741 .1296 L
s
.41366 .09061 m
.41741 .09061 L
s
.41366 .05163 m
.41741 .05163 L
s
.41366 .01264 m
.41741 .01264 L
s
.25 Mabswid
.41366 0 m
.41366 .97142 L
s
0 0 m
1 0 L
1 .97142 L
0 .97142 L
closepath
clip
newpath
1 0 0 r
.01 w
.80351 .94829 m
.02381 .94829 L
.02381 .16859 L
.80351 .16859 L
.80351 .94829 L
s
0 0 1 r
.92813 .85089 m
.14843 .80283 L
.19649 .02313 L
.97619 .07119 L
.92813 .85089 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 279.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{1173, 945},
WindowMargins->{{-6, Automatic}, {22, Automatic}},
StyleDefinitions -> "DemoText.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 200, 5, 205, "Title"],
Cell[1957, 58, 111, 3, 121, "Input"],

Cell[CellGroupData[{
Cell[2093, 65, 67, 1, 67, "Subtitle"],
Cell[2163, 68, 1152, 24, 829, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3352, 97, 70, 2, 65, "Input"],
Cell[3425, 101, 35, 1, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3497, 107, 77, 1, 67, "Subtitle"],

Cell[CellGroupData[{
Cell[3599, 112, 439, 10, 159, "Input"],
Cell[4041, 124, 731, 13, 273, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4821, 143, 109, 4, 67, "Subtitle"],

Cell[CellGroupData[{
Cell[4955, 151, 149, 3, 121, "Input"],
Cell[5107, 156, 145, 2, 52, "Output"],
Cell[5255, 160, 502, 7, 115, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5806, 173, 111, 4, 67, "Subtitle"],

Cell[CellGroupData[{
Cell[5942, 181, 170, 5, 121, "Input"],
Cell[6115, 188, 145, 2, 52, "Output"],
Cell[6263, 192, 575, 9, 115, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6887, 207, 44, 1, 67, "Subtitle"],

Cell[CellGroupData[{
Cell[6956, 212, 424, 10, 170, "Input"],
Cell[7383, 224, 957, 17, 100, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8377, 246, 1274, 26, 1033, "Input"],
Cell[9654, 274, 830, 12, 117, "Output"],
Cell[10487, 288, 618, 9, 205, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11154, 303, 67, 1, 67, "Subtitle"],

Cell[CellGroupData[{
Cell[11246, 308, 128, 3, 121, "Input"],
Cell[11377, 313, 40, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11454, 319, 487, 9, 283, "Input"],
Cell[11944, 330, 259, 4, 70, "Output"],
Cell[12206, 336, 282, 7, 70, "Output"],
Cell[12491, 345, 1228, 23, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[13768, 374, 52, 1, 71, "Subtitle"],

Cell[CellGroupData[{
Cell[13845, 379, 65, 1, 67, "Subtitle"],

Cell[CellGroupData[{
Cell[13935, 384, 295, 8, 169, "Input"],
Cell[14233, 394, 232, 3, 70, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14514, 403, 586, 12, 445, "Input"],
Cell[15103, 417, 259, 4, 70, "Output"],
Cell[15365, 423, 3202, 48, 70, "Output"]
}, Open  ]],
Cell[18582, 474, 73, 2, 67, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[18692, 481, 75, 1, 71, "Subtitle"],

Cell[CellGroupData[{
Cell[18792, 486, 265, 6, 238, "Input"],
Cell[19060, 494, 1457, 25, 70, "Output"],
Cell[20520, 521, 249, 4, 70, "Output"],
Cell[20772, 527, 1795, 31, 70, "Output"]
}, Open  ]],
Cell[22582, 561, 578, 13, 445, "Input"],

Cell[CellGroupData[{
Cell[23185, 578, 340, 6, 283, "Input"],
Cell[23528, 586, 59, 1, 70, "Output"],
Cell[23590, 589, 59, 1, 70, "Output"],
Cell[23652, 592, 103, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23792, 599, 170, 3, 121, "Input"],
Cell[23965, 604, 43, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24045, 610, 296, 7, 391, "Input"],
Cell[24344, 619, 2770, 212, 70, 2651, 208, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[27117, 833, 3523, 260, 70, 3400, 256, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[30643, 1095, 3406, 248, 70, 3283, 244, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[34052, 1345, 3468, 254, 70, 3346, 250, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[37523, 1601, 3476, 254, 70, 3350, 250, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[41002, 1857, 3541, 260, 70, 3422, 256, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[44546, 2119, 3286, 236, 70, 3163, 232, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[47835, 2357, 3403, 242, 70, 3281, 238, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

